@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,19 +12,15 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 """PyMC-ArviZ conversion code."""
+
 import logging
 import warnings
 
-from typing import (  # pylint: disable=unused-import
+from collections.abc import Iterable, Mapping
+from typing import (
     TYPE_CHECKING,
     Any,
-    Dict,
-    Iterable,
-    List,
-    Mapping,
     Optional,
-    Sequence,
-    Tuple,
     Union,
 )
 
@@ -42,17 +38,17 @@ from pymc.pytensorf import extract_obs_data
 from pymc.util import get_default_varnames
 
 if TYPE_CHECKING:
-    from pymc.backends.base import MultiTrace  # pylint: disable=invalid-name
+    from pymc.backends.base import MultiTrace
 
 ___all__ = [""]
 
 _log = logging.getLogger(__name__)
 
 # random variable object ...
-Var = Any  # pylint: disable=invalid-name
+Var = Any
 
 
-def find_observations(model: "Model") -> Dict[str, Var]:
+def find_observations(model: "Model") -> dict[str, Var]:
     """If there are observations available, return them as a dictionary."""
     observations = {}
     for obs in model.observed_RVs:
@@ -69,7 +65,7 @@ def find_observations(model: "Model") -> Dict[str, Var]:
     return observations
 
 
-def find_constants(model: "Model") -> Dict[str, Var]:
+def find_constants(model: "Model") -> dict[str, Var]:
     """If there are constants available, return them as a dictionary."""
 
     # The constant data vars must be either pm.Data or TensorConstant or SharedVariable
@@ -100,7 +96,7 @@ def find_constants(model: "Model") -> Dict[str, Var]:
     return constant_data
 
 
-def coords_and_dims_for_inferencedata(model: Model) -> Tuple[Dict[str, Any], Dict[str, Any]]:
+def coords_and_dims_for_inferencedata(model: Model) -> tuple[dict[str, Any], dict[str, Any]]:
     """Parse PyMC model coords and dims format to one accepted by InferenceData."""
     coords = {
         cname: np.array(cvals) if isinstance(cvals, tuple) else cvals
@@ -135,7 +131,7 @@ class _DefaultTrace:
 
     def __init__(self, samples: int):
         self._len: int = samples
-        self.trace_dict: Dict[str, np.ndarray] = {}
+        self.trace_dict: dict[str, np.ndarray] = {}
 
     def insert(self, k: str, v, idx: int):
         """
@@ -154,7 +150,7 @@ class _DefaultTrace:
 
         # initialize if necessary
         if k not in self.trace_dict:
-            array_shape = (self._len,) + value_shape
+            array_shape = (self._len, *value_shape)
             self.trace_dict[k] = np.empty(array_shape, dtype=np.array(v).dtype)
 
         # do the actual insertion
@@ -164,7 +160,7 @@ class _DefaultTrace:
             self.trace_dict[k][idx, :] = v
 
 
-class InferenceDataConverter:  # pylint: disable=too-many-instance-attributes
+class InferenceDataConverter:
     """Encapsulate InferenceData specific logic."""
 
     model: Optional[Model] = None
@@ -179,10 +175,11 @@ class InferenceDataConverter:  # pylint: disable=too-many-instance-attributes
         prior=None,
         posterior_predictive=None,
         log_likelihood=False,
+        log_prior=False,
         predictions=None,
         coords: Optional[CoordSpec] = None,
         dims: Optional[DimSpec] = None,
-        sample_dims: Optional[List] = None,
+        sample_dims: Optional[list] = None,
         model=None,
         save_warmup: Optional[bool] = None,
         include_transformed: bool = False,
@@ -220,6 +217,7 @@ class InferenceDataConverter:  # pylint: disable=too-many-instance-attributes
         self.prior = prior
         self.posterior_predictive = posterior_predictive
         self.log_likelihood = log_likelihood
+        self.log_prior = log_prior
         self.predictions = predictions
 
         if all(elem is None for elem in (trace, predictions, posterior_predictive, prior)):
@@ -240,7 +238,7 @@ class InferenceDataConverter:  # pylint: disable=too-many-instance-attributes
 
         self.observations = find_observations(self.model)
 
-    def split_trace(self) -> Tuple[Union[None, "MultiTrace"], Union[None, "MultiTrace"]]:
+    def split_trace(self) -> tuple[Union[None, "MultiTrace"], Union[None, "MultiTrace"]]:
         """Split MultiTrace object into posterior and warmup.
 
         Returns
@@ -441,7 +439,7 @@ class InferenceDataConverter:  # pylint: disable=too-many-instance-attributes
             id_dict["constant_data"] = self.constant_data_to_xarray()
         idata = InferenceData(save_warmup=self.save_warmup, **id_dict)
         if self.log_likelihood:
-            from pymc.stats.log_likelihood import compute_log_likelihood
+            from pymc.stats.log_density import compute_log_likelihood
 
             idata = compute_log_likelihood(
                 idata,
@@ -451,6 +449,17 @@ class InferenceDataConverter:  # pylint: disable=too-many-instance-attributes
                 sample_dims=self.sample_dims,
                 progressbar=False,
             )
+        if self.log_prior:
+            from pymc.stats.log_density import compute_log_prior
+
+            idata = compute_log_prior(
+                idata,
+                var_names=None if self.log_prior is True else self.log_prior,
+                extend_inferencedata=True,
+                model=self.model,
+                sample_dims=self.sample_dims,
+                progressbar=False,
+            )
         return idata
 
 
@@ -460,9 +469,10 @@ def to_inference_data(
     prior: Optional[Mapping[str, Any]] = None,
     posterior_predictive: Optional[Mapping[str, Any]] = None,
     log_likelihood: Union[bool, Iterable[str]] = False,
+    log_prior: Union[bool, Iterable[str]] = False,
     coords: Optional[CoordSpec] = None,
     dims: Optional[DimSpec] = None,
-    sample_dims: Optional[List] = None,
+    sample_dims: Optional[list] = None,
     model: Optional["Model"] = None,
     save_warmup: Optional[bool] = None,
     include_transformed: bool = False,
@@ -486,8 +496,11 @@ def to_inference_data(
         Dictionary with the variable names as keys, and values numpy arrays
         containing posterior predictive samples.
     log_likelihood : bool or array_like of str, optional
-        List of variables to calculate `log_likelihood`. Defaults to True which calculates
-        `log_likelihood` for all observed variables. If set to False, log_likelihood is skipped.
+        List of variables to calculate `log_likelihood`. Defaults to False.
+        If set to True, computes `log_likelihood` for all observed variables.
+    log_prior : bool or array_like of str, optional
+        List of variables to calculate `log_prior`. Defaults to False.
+        If set to True, computes `log_prior` for all unobserved variables.
     coords : dict of {str: array-like}, optional
         Map of coordinate names to coordinate values
     dims : dict of {str: list of str}, optional
@@ -514,6 +527,7 @@ def to_inference_data(
         prior=prior,
         posterior_predictive=posterior_predictive,
         log_likelihood=log_likelihood,
+        log_prior=log_prior,
         coords=coords,
         dims=dims,
         sample_dims=sample_dims,
@@ -531,7 +545,7 @@ def predictions_to_inference_data(
     model: Optional["Model"] = None,
     coords: Optional[CoordSpec] = None,
     dims: Optional[DimSpec] = None,
-    sample_dims: Optional[List] = None,
+    sample_dims: Optional[list] = None,
     idata_orig: Optional[InferenceData] = None,
     inplace: bool = False,
 ) -> InferenceData:
