@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -49,7 +49,6 @@ from pymc.distributions.distribution import Discrete
 from pymc.distributions.shape_utils import rv_size_is_none
 from pymc.logprob.basic import logcdf, logp
 from pymc.math import sigmoid
-from pymc.pytensorf import floatX, intX
 
 __all__ = [
     "Binomial",
@@ -112,6 +111,7 @@ class Binomial(Discrete):
     logit_p : tensor_like of float
         Alternative log odds for the probability of success.
     """
+
     rv_op = binomial
 
     @classmethod
@@ -124,11 +124,11 @@ class Binomial(Discrete):
         if logit_p is not None:
             p = pt.sigmoid(logit_p)
 
-        n = pt.as_tensor_variable(intX(n))
-        p = pt.as_tensor_variable(floatX(p))
+        n = pt.as_tensor_variable(n, dtype=int)
+        p = pt.as_tensor_variable(p)
         return super().dist([n, p], **kwargs)
 
-    def moment(rv, size, n, p):
+    def support_point(rv, size, n, p):
         mean = pt.round(n * p)
         if not rv_size_is_none(size):
             mean = pt.full(size, mean)
@@ -232,12 +232,12 @@ class BetaBinomial(Discrete):
 
     @classmethod
     def dist(cls, alpha, beta, n, *args, **kwargs):
-        alpha = pt.as_tensor_variable(floatX(alpha))
-        beta = pt.as_tensor_variable(floatX(beta))
-        n = pt.as_tensor_variable(intX(n))
+        alpha = pt.as_tensor_variable(alpha)
+        beta = pt.as_tensor_variable(beta)
+        n = pt.as_tensor_variable(n, dtype=int)
         return super().dist([n, alpha, beta], **kwargs)
 
-    def moment(rv, size, n, alpha, beta):
+    def support_point(rv, size, n, alpha, beta):
         mean = pt.round((n * alpha) / (alpha + beta))
         if not rv_size_is_none(size):
             mean = pt.full(size, mean)
@@ -334,6 +334,7 @@ class Bernoulli(Discrete):
     logit_p : tensor_like of float
         Alternative log odds for the probability of success.
     """
+
     rv_op = bernoulli
 
     @classmethod
@@ -346,10 +347,10 @@ class Bernoulli(Discrete):
         if logit_p is not None:
             p = pt.sigmoid(logit_p)
 
-        p = pt.as_tensor_variable(floatX(p))
+        p = pt.as_tensor_variable(p)
         return super().dist([p], **kwargs)
 
-    def moment(rv, size, p):
+    def support_point(rv, size, p):
         if not rv_size_is_none(size):
             p = pt.full(size, p)
         return pt.switch(p < 0.5, 0, 1)
@@ -450,15 +451,16 @@ class DiscreteWeibull(Discrete):
         Shape parameter (beta > 0).
 
     """
+
     rv_op = discrete_weibull
 
     @classmethod
     def dist(cls, q, beta, *args, **kwargs):
-        q = pt.as_tensor_variable(floatX(q))
-        beta = pt.as_tensor_variable(floatX(beta))
+        q = pt.as_tensor_variable(q)
+        beta = pt.as_tensor_variable(beta)
         return super().dist([q, beta], **kwargs)
 
-    def moment(rv, size, q, beta):
+    def support_point(rv, size, q, beta):
         median = pt.power(pt.log(0.5) / pt.log(q), 1 / beta) - 1
         if not rv_size_is_none(size):
             median = pt.full(size, median)
@@ -539,14 +541,15 @@ class Poisson(Discrete):
     The Poisson distribution can be derived as a limiting case of the
     binomial distribution.
     """
+
     rv_op = poisson
 
     @classmethod
     def dist(cls, mu, *args, **kwargs):
-        mu = pt.as_tensor_variable(floatX(mu))
+        mu = pt.as_tensor_variable(mu)
         return super().dist([mu], *args, **kwargs)
 
-    def moment(rv, size, mu):
+    def support_point(rv, size, mu):
         mu = pt.floor(mu)
         if not rv_size_is_none(size):
             mu = pt.full(size, mu)
@@ -662,13 +665,14 @@ class NegativeBinomial(Discrete):
     n : tensor_like of float
         Alternative number of target success trials (n > 0)
     """
+
     rv_op = nbinom
 
     @classmethod
     def dist(cls, mu=None, alpha=None, p=None, n=None, *args, **kwargs):
         n, p = cls.get_n_p(mu=mu, alpha=alpha, p=p, n=n)
-        n = pt.as_tensor_variable(floatX(n))
-        p = pt.as_tensor_variable(floatX(p))
+        n = pt.as_tensor_variable(n)
+        p = pt.as_tensor_variable(p)
         return super().dist([n, p], *args, **kwargs)
 
     @classmethod
@@ -691,7 +695,7 @@ class NegativeBinomial(Discrete):
 
         return n, p
 
-    def moment(rv, size, n, p):
+    def support_point(rv, size, n, p):
         mu = pt.floor(n * (1 - p) / p)
         if not rv_size_is_none(size):
             mu = pt.full(size, mu)
@@ -779,10 +783,10 @@ class Geometric(Discrete):
 
     @classmethod
     def dist(cls, p, *args, **kwargs):
-        p = pt.as_tensor_variable(floatX(p))
+        p = pt.as_tensor_variable(p)
         return super().dist([p], *args, **kwargs)
 
-    def moment(rv, size, p):
+    def support_point(rv, size, p):
         mean = pt.round(1.0 / p)
         if not rv_size_is_none(size):
             mean = pt.full(size, mean)
@@ -880,12 +884,12 @@ class HyperGeometric(Discrete):
 
     @classmethod
     def dist(cls, N, k, n, *args, **kwargs):
-        good = pt.as_tensor_variable(intX(k))
-        bad = pt.as_tensor_variable(intX(N - k))
-        n = pt.as_tensor_variable(intX(n))
+        good = pt.as_tensor_variable(k, dtype=int)
+        bad = pt.as_tensor_variable(N - k, dtype=int)
+        n = pt.as_tensor_variable(n, dtype=int)
         return super().dist([good, bad, n], *args, **kwargs)
 
-    def moment(rv, size, good, bad, n):
+    def support_point(rv, size, good, bad, n):
         N, k = good + bad, good
         mode = pt.floor((n + 1) * (k + 1) / (N + 2))
         if not rv_size_is_none(size):
@@ -1017,11 +1021,11 @@ class DiscreteUniform(Discrete):
 
     @classmethod
     def dist(cls, lower, upper, *args, **kwargs):
-        lower = intX(pt.floor(lower))
-        upper = intX(pt.floor(upper))
+        lower = pt.floor(lower)
+        upper = pt.floor(upper)
         return super().dist([lower, upper], **kwargs)
 
-    def moment(rv, size, lower, upper):
+    def support_point(rv, size, lower, upper):
         mode = pt.maximum(pt.floor((upper + lower) / 2.0), lower)
         if not rv_size_is_none(size):
             mode = pt.full(size, mode)
@@ -1108,6 +1112,7 @@ class Categorical(Discrete):
     logit_p : float
         Alternative log odds for the probability of success.
     """
+
     rv_op = categorical
 
     @classmethod
@@ -1137,7 +1142,7 @@ class Categorical(Discrete):
                 p = pt.as_tensor_variable(p_)
         return super().dist([p], **kwargs)
 
-    def moment(rv, size, p):
+    def support_point(rv, size, p):
         mode = pt.argmax(p, axis=-1)
         if not rv_size_is_none(size):
             mode = pt.full(size, mode)
@@ -1153,7 +1158,7 @@ class Categorical(Discrete):
                 value_clip = pt.shape_padleft(value_clip, p_.ndim - value_clip.ndim)
             elif p.ndim < value_clip.ndim:
                 p = pt.shape_padleft(p, value_clip.ndim - p_.ndim)
-            pattern = (p.ndim - 1,) + tuple(range(p.ndim - 1))
+            pattern = (p.ndim - 1, *range(p.ndim - 1))
             a = pt.log(
                 pt.take_along_axis(
                     p.dimshuffle(pattern),
@@ -1183,11 +1188,12 @@ class _OrderedLogistic(Categorical):
     Underlying class for ordered logistic distributions.
     See docs for the OrderedLogistic wrapper class for more details on how to use it in models.
     """
+
     rv_op = categorical
 
     @classmethod
     def dist(cls, eta, cutpoints, *args, **kwargs):
-        eta = pt.as_tensor_variable(floatX(eta))
+        eta = pt.as_tensor_variable(eta)
         cutpoints = pt.as_tensor_variable(cutpoints)
 
         pa = sigmoid(cutpoints - pt.shape_padright(eta))
@@ -1289,11 +1295,12 @@ class _OrderedProbit(Categorical):
     Underlying class for ordered probit distributions.
     See docs for the OrderedProbit wrapper class for more details on how to use it in models.
     """
+
     rv_op = categorical
 
     @classmethod
     def dist(cls, eta, cutpoints, sigma=1, *args, **kwargs):
-        eta = pt.as_tensor_variable(floatX(eta))
+        eta = pt.as_tensor_variable(eta)
         cutpoints = pt.as_tensor_variable(cutpoints)
 
         probits = pt.shape_padright(eta) - cutpoints
@@ -1307,7 +1314,7 @@ class _OrderedProbit(Categorical):
             ],
             axis=-1,
         )
-        _log_p = pt.as_tensor_variable(floatX(_log_p))
+        _log_p = pt.as_tensor_variable(_log_p)
         p = pt.exp(_log_p)
 
         return super().dist(p, *args, **kwargs)
