@@ -535,6 +535,14 @@ def support_point(rv: TensorVariable) -> TensorVariable:
     return _support_point(rv.owner.op, rv, *rv.owner.inputs).astype(rv.dtype)
 
 
+def _moment(op, rv, *rv_inputs) -> TensorVariable:
+    warnings.warn(
+        "The moment() method is deprecated. Use support_point() instead.",
+        DeprecationWarning,
+    )
+    return _support_point(op, rv, *rv_inputs)
+
+
 def moment(rv: TensorVariable) -> TensorVariable:
     warnings.warn(
         "The moment() method is deprecated. Use support_point() instead.",
@@ -663,6 +671,7 @@ class _CustomDist(Distribution):
                 ndim_supp=ndim_supp,
                 ndims_params=ndims_params,
                 dtype=dtype,
+                _print_name=(class_name, f"\\operatorname{{{class_name}}}"),
                 # Specific to CustomDist
                 _random_fn=random,
             ),
@@ -802,6 +811,7 @@ class _CustomSymbolicDist(Distribution):
             # If logp is not provided, we try to infer it from the dist graph
             dict(
                 inline_logprob=logp is None,
+                _print_name=(class_name, f"\\operatorname{{{class_name}}}"),
             ),
         )
 
