@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -30,9 +30,8 @@ from pytensor.graph.op import Op
 from pytensor.raise_op import Assert
 from pytensor.sparse.basic import sp_sum
 from pytensor.tensor import TensorConstant, gammaln, sigmoid
-from pytensor.tensor.linalg import cholesky, det, eigh
+from pytensor.tensor.linalg import cholesky, det, eigh, solve_triangular, trace
 from pytensor.tensor.linalg import inv as matrix_inverse
-from pytensor.tensor.linalg import solve_triangular, trace
 from pytensor.tensor.random.basic import dirichlet, multinomial, multivariate_normal
 from pytensor.tensor.random.op import RandomVariable
 from pytensor.tensor.random.utils import (
@@ -58,8 +57,8 @@ from pymc.distributions.distribution import (
     Discrete,
     Distribution,
     SymbolicRandomVariable,
-    _moment,
-    moment,
+    _support_point,
+    support_point,
 )
 from pymc.distributions.shape_utils import (
     _change_dist_size,
@@ -72,7 +71,7 @@ from pymc.distributions.shape_utils import (
 from pymc.distributions.transforms import Interval, ZeroSumTransform, _default_transform
 from pymc.logprob.abstract import _logprob
 from pymc.math import kron_diag, kron_dot
-from pymc.pytensorf import floatX, intX
+from pymc.pytensorf import intX
 from pymc.util import check_dist_not_registered
 
 __all__ = [
@@ -235,6 +234,7 @@ class MvNormal(Continuous):
         vals_raw = pm.Normal('vals_raw', mu=0, sigma=1, shape=(5, 3))
         vals = pm.Deterministic('vals', pt.dot(chol, vals_raw.T).T)
     """
+
     rv_op = multivariate_normal
 
     @classmethod
@@ -245,13 +245,13 @@ class MvNormal(Continuous):
         mu, _ = pt.broadcast_arrays(mu, cov[..., -1])
         return super().dist([mu, cov], **kwargs)
 
-    def moment(rv, size, mu, cov):
+    def support_point(rv, size, mu, cov):
         # mu is broadcasted to the potential length of cov in `dist`
-        moment = mu
+        support_point = mu
         if not rv_size_is_none(size):
-            moment_size = pt.concatenate([size, [mu.shape[-1]]])
-            moment = pt.full(moment_size, mu)
-        return moment
+            support_point_size = pt.concatenate([size, [mu.shape[-1]]])
+            support_point = pt.full(support_point_size, mu)
+        return support_point
 
     def logp(value, mu, cov):
         """
@@ -268,8 +268,8 @@ class MvNormal(Continuous):
         TensorVariable
         """
         quaddist, logdet, ok = quaddist_chol(value, mu, cov)
-        k = floatX(value.shape[-1])
-        norm = -0.5 * k * pm.floatX(np.log(2 * np.pi))
+        k = value.shape[-1].astype("floatX")
+        norm = -0.5 * k * np.log(2 * np.pi)
         return check_parameters(
             norm - 0.5 * quaddist - logdet,
             ok,
@@ -355,6 +355,7 @@ class MvStudentT(Continuous):
     lower : bool, default=True
         Whether the cholesky fatcor is given as a lower triangular matrix.
     """
+
     rv_op = mv_studentt
 
     @classmethod
@@ -371,22 +372,22 @@ class MvStudentT(Continuous):
             if scale is not None:
                 raise ValueError("Specify only one of scale and Sigma")
             scale = Sigma
-        nu = pt.as_tensor_variable(floatX(nu))
-        mu = pt.as_tensor_variable(floatX(mu))
+        nu = pt.as_tensor_variable(nu)
+        mu = pt.as_tensor_variable(mu)
         scale = quaddist_matrix(scale, chol, tau, lower)
         # PyTensor is stricter about the shape of mu, than PyMC used to be
         mu, _ = pt.broadcast_arrays(mu, scale[..., -1])
 
         return super().dist([nu, mu, scale], **kwargs)
 
-    def moment(rv, size, nu, mu, scale):
+    def support_point(rv, size, nu, mu, scale):
         # mu is broadcasted to the potential length of scale in `dist`
         mu, _ = pt.random.utils.broadcast_params([mu, nu], ndims_params=[1, 0])
-        moment = mu
+        support_point = mu
         if not rv_size_is_none(size):
-            moment_size = pt.concatenate([size, [mu.shape[-1]]])
-            moment = pt.full(moment_size, moment)
-        return moment
+            support_point_size = pt.concatenate([size, [mu.shape[-1]]])
+            support_point = pt.full(support_point_size, support_point)
+        return support_point
 
     def logp(value, nu, mu, scale):
         """
@@ -403,7 +404,7 @@ class MvStudentT(Continuous):
         TensorVariable
         """
         quaddist, logdet, ok = quaddist_chol(value, mu, scale)
-        k = floatX(value.shape[-1])
+        k = value.shape[-1].astype("floatX")
 
         norm = gammaln((nu + k) / 2.0) - gammaln(nu / 2.0) - 0.5 * k * pt.log(nu * np.pi)
         inner = -(nu + k) / 2.0 * pt.log1p(quaddist / nu)
@@ -436,6 +437,7 @@ class Dirichlet(SimplexContinuous):
         Concentration parameters (a > 0). The number of categories is given by the
         length of the last axis.
     """
+
     rv_op = dirichlet
 
     @classmethod
@@ -446,12 +448,12 @@ class Dirichlet(SimplexContinuous):
 
         return super().dist([a], **kwargs)
 
-    def moment(rv, size, a):
+    def support_point(rv, size, a):
         norm_constant = pt.sum(a, axis=-1)[..., None]
-        moment = a / norm_constant
+        support_point = a / norm_constant
         if not rv_size_is_none(size):
-            moment = pt.full(pt.concatenate([size, [a.shape[-1]]]), moment)
-        return moment
+            support_point = pt.full(pt.concatenate([size, [a.shape[-1]]]), support_point)
+        return support_point
 
     def logp(value, a):
         """
@@ -515,6 +517,7 @@ class Multinomial(Discrete):
         categories is given by the length of the last axis. Elements are expected to sum
         to 1 along the last axis.
     """
+
     rv_op = multinomial
 
     @classmethod
@@ -538,7 +541,7 @@ class Multinomial(Discrete):
         p = pt.as_tensor_variable(p)
         return super().dist([n, p], *args, **kwargs)
 
-    def moment(rv, size, n, p):
+    def support_point(rv, size, n, p):
         n = pt.shape_padright(n)
         mean = n * p
         mode = pt.round(mean)
@@ -554,7 +557,7 @@ class Multinomial(Discrete):
             output_size = pt.concatenate([size, [p.shape[-1]]])
             mode = pt.full(output_size, mode)
         return Assert(
-            "Negative value in computed moment of Multinomial."
+            "Negative value in computed support_point of Multinomial."
             "It is a known limitation that can arise when the expected largest count is small."
             "Please provide an initial value manually."
         )(mode, pt.all(mode >= 0))
@@ -613,7 +616,7 @@ class DirichletMultinomialRV(RandomVariable):
 
             if size:
                 n = np.broadcast_to(n, size)
-                a = np.broadcast_to(a, size + (a.shape[-1],))
+                a = np.broadcast_to(a, (*size, a.shape[-1]))
 
             res = np.empty(a.shape)
             for idx in np.ndindex(a.shape[:-1]):
@@ -662,18 +665,16 @@ class DirichletMultinomial(Discrete):
         Dirichlet concentration parameters (a > 0). The number of categories is given by
         the length of the last axis.
     """
+
     rv_op = dirichlet_multinomial
 
     @classmethod
     def dist(cls, n, a, *args, **kwargs):
-        n = intX(n)
-        a = floatX(a)
-
         return super().dist([n, a], **kwargs)
 
-    def moment(rv, size, n, a):
+    def support_point(rv, size, n, a):
         p = a / pt.sum(a, axis=-1, keepdims=True)
-        return moment(Multinomial.dist(n=n, p=p, size=size))
+        return support_point(Multinomial.dist(n=n, p=p, size=size))
 
     def logp(value, n, a):
         """
@@ -716,13 +717,14 @@ class _OrderedMultinomial(Multinomial):
     Underlying class for ordered multinomial distributions.
     See docs for the OrderedMultinomial wrapper class for more details on how to use it in models.
     """
+
     rv_op = multinomial
 
     @classmethod
     def dist(cls, eta, cutpoints, n, *args, **kwargs):
-        eta = pt.as_tensor_variable(floatX(eta))
+        eta = pt.as_tensor_variable(eta)
         cutpoints = pt.as_tensor_variable(cutpoints)
-        n = pt.as_tensor_variable(intX(n))
+        n = pt.as_tensor_variable(n, dtype=int)
 
         pa = sigmoid(cutpoints - pt.shape_padright(eta))
         p_cum = pt.concatenate(
@@ -940,12 +942,13 @@ class Wishart(Continuous):
     This distribution is unusable in a PyMC model. You should instead
     use LKJCholeskyCov or LKJCorr.
     """
+
     rv_op = wishart
 
     @classmethod
     def dist(cls, nu, V, *args, **kwargs):
         nu = pt.as_tensor_variable(intX(nu))
-        V = pt.as_tensor_variable(floatX(V))
+        V = pt.as_tensor_variable(V)
 
         warnings.warn(
             "The Wishart distribution can currently not be used "
@@ -1160,6 +1163,8 @@ _ljk_cholesky_cov_base = _LKJCholeskyCovBaseRV()
 # be safely resized. Because of this, we add the thin SymbolicRandomVariable wrapper
 class _LKJCholeskyCovRV(SymbolicRandomVariable):
     default_output = 1
+    signature = "(),(),(),(n)->(),(n)"
+    ndim_supp = 1
     _print_name = ("_lkjcholeskycov", "\\operatorname{_lkjcholeskycov}")
 
     def update(self, node):
@@ -1175,8 +1180,8 @@ class _LKJCholeskyCov(Distribution):
 
     @classmethod
     def dist(cls, n, eta, sd_dist, **kwargs):
-        n = pt.as_tensor_variable(intX(n))
-        eta = pt.as_tensor_variable(floatX(eta))
+        n = pt.as_tensor_variable(n, dtype=int)
+        eta = pt.as_tensor_variable(eta)
 
         if not (
             isinstance(sd_dist, Variable)
@@ -1199,7 +1204,7 @@ class _LKJCholeskyCov(Distribution):
         # implied batched dimensions from those for the time being.
         if size is None:
             size = sd_dist.shape[:-1]
-        shape = tuple(size) + (n,)
+        shape = (*size, n)
         if sd_dist.owner.op.ndim_supp == 0:
             sd_dist = change_dist_size(sd_dist, shape)
         else:
@@ -1215,7 +1220,6 @@ class _LKJCholeskyCov(Distribution):
         return _LKJCholeskyCovRV(
             inputs=[rng_, n_, eta_, sd_dist_],
             outputs=[next_rng_, lkjcov_],
-            ndim_supp=1,
         )(rng, n, eta, sd_dist)
 
 
@@ -1230,12 +1234,12 @@ def change_LKJCholeksyCovRV_size(op, dist, new_size, expand=False):
     return _LKJCholeskyCov.rv_op(n, eta, sd_dist, size=new_size)
 
 
-@_moment.register(_LKJCholeskyCovRV)
-def _LKJCholeksyCovRV_moment(op, rv, rng, n, eta, sd_dist):
+@_support_point.register(_LKJCholeskyCovRV)
+def _LKJCholeksyCovRV_support_point(op, rv, rng, n, eta, sd_dist):
     diag_idxs = (pt.cumsum(pt.arange(1, n + 1)) - 1).astype("int32")
-    moment = pt.zeros_like(rv)
-    moment = pt.set_subtensor(moment[..., diag_idxs], 1)
-    return moment
+    support_point = pt.zeros_like(rv)
+    support_point = pt.set_subtensor(support_point[..., diag_idxs], 1)
+    return support_point
 
 
 @_default_transform.register(_LKJCholeskyCovRV)
@@ -1505,6 +1509,7 @@ class LKJCorrRV(RandomVariable):
     def _random_corr_matrix(cls, rng, n, eta, flat_size):
         # original implementation in R see:
         # https://github.com/rmcelreath/rethinking/blob/master/R/distributions.r
+
         beta = eta - 1.0 + n / 2.0
         r12 = 2.0 * stats.beta.rvs(a=beta, b=beta, size=flat_size, random_state=rng) - 1.0
         P = np.full((flat_size, n, n), np.eye(n))
@@ -1531,57 +1536,17 @@ class MultivariateIntervalTransform(Interval):
         return super().log_jac_det(*args).sum(-1)
 
 
-class LKJCorr(BoundedContinuous):
-    r"""
-    The LKJ (Lewandowski, Kurowicka and Joe) log-likelihood.
-
-    The LKJ distribution is a prior distribution for correlation matrices.
-    If eta = 1 this corresponds to the uniform distribution over correlation
-    matrices. For eta -> oo the LKJ prior approaches the identity matrix.
-
-    ========  ==============================================
-    Support   Upper triangular matrix with values in [-1, 1]
-    ========  ==============================================
-
-    Parameters
-    ----------
-    n : tensor_like of int
-        Dimension of the covariance matrix (n > 1).
-    eta : tensor_like of float
-        The shape parameter (eta > 0) of the LKJ distribution. eta = 1
-        implies a uniform distribution of the correlation matrices;
-        larger values put more weight on matrices with few correlations.
-
-    Notes
-    -----
-    This implementation only returns the values of the upper triangular
-    matrix excluding the diagonal. Here is a schematic for n = 5, showing
-    the indexes of the elements::
-
-        [[- 0 1 2 3]
-         [- - 4 5 6]
-         [- - - 7 8]
-         [- - - - 9]
-         [- - - - -]]
-
-
-    References
-    ----------
-    .. [LKJ2009] Lewandowski, D., Kurowicka, D. and Joe, H. (2009).
-        "Generating random correlation matrices based on vines and
-        extended onion method." Journal of multivariate analysis,
-        100(9), pp.1989-2001.
-    """
-
+# Returns list of upper triangular values
+class _LKJCorr(BoundedContinuous):
     rv_op = lkjcorr
 
     @classmethod
     def dist(cls, n, eta, **kwargs):
-        n = pt.as_tensor_variable(intX(n))
-        eta = pt.as_tensor_variable(floatX(eta))
+        n = pt.as_tensor_variable(n).astype(int)
+        eta = pt.as_tensor_variable(eta)
         return super().dist([n, eta], **kwargs)
 
-    def moment(rv, *args):
+    def support_point(rv, *args):
         return pt.zeros_like(rv)
 
     def logp(value, n, eta):
@@ -1631,9 +1596,95 @@ class LKJCorr(BoundedContinuous):
         )
 
 
-@_default_transform.register(LKJCorr)
+@_default_transform.register(_LKJCorr)
 def lkjcorr_default_transform(op, rv):
-    return MultivariateIntervalTransform(floatX(-1.0), floatX(1.0))
+    return MultivariateIntervalTransform(-1.0, 1.0)
+
+
+class LKJCorr:
+    r"""
+    The LKJ (Lewandowski, Kurowicka and Joe) log-likelihood.
+
+    The LKJ distribution is a prior distribution for correlation matrices.
+    If eta = 1 this corresponds to the uniform distribution over correlation
+    matrices. For eta -> oo the LKJ prior approaches the identity matrix.
+
+    ========  ==============================================
+    Support   Upper triangular matrix with values in [-1, 1]
+    ========  ==============================================
+
+    Parameters
+    ----------
+    n : tensor_like of int
+        Dimension of the covariance matrix (n > 1).
+    eta : tensor_like of float
+        The shape parameter (eta > 0) of the LKJ distribution. eta = 1
+        implies a uniform distribution of the correlation matrices;
+        larger values put more weight on matrices with few correlations.
+    return_matrix : bool, default=False
+        If True, returns the full correlation matrix.
+        False only returns the values of the upper triangular matrix excluding
+        diagonal in a single vector of length n(n-1)/2 for memory efficiency
+
+    Notes
+    -----
+    This is mainly useful if you want the standard deviations to be fixed, as
+    LKJCholsekyCov is optimized for the case where they come from a distribution.
+
+    Examples
+    --------
+    .. code:: python
+
+        with pm.Model() as model:
+
+            # Define the vector of fixed standard deviations
+            sds = 3*np.ones(10)
+
+            corr = pm.LKJCorr(
+                'corr', eta=4, n=10, return_matrix=True
+            )
+
+            # Define a new MvNormal with the given correlation matrix
+            vals = sds*pm.MvNormal('vals', mu=np.zeros(10), cov=corr, shape=10)
+
+            # Or transform an uncorrelated normal distribution:
+            vals_raw = pm.Normal('vals_raw', shape=10)
+            chol = pt.linalg.cholesky(corr)
+            vals = sds*pt.dot(chol,vals_raw)
+
+            # The matrix is internally still sampled as a upper triangular vector
+            # If you want access to it in matrix form in the trace, add
+            pm.Deterministic('corr_mat', corr)
+
+
+    References
+    ----------
+    .. [LKJ2009] Lewandowski, D., Kurowicka, D. and Joe, H. (2009).
+        "Generating random correlation matrices based on vines and
+        extended onion method." Journal of multivariate analysis,
+        100(9), pp.1989-2001.
+    """
+
+    def __new__(cls, name, n, eta, *, return_matrix=False, **kwargs):
+        c_vec = _LKJCorr(name, eta=eta, n=n, **kwargs)
+        if not return_matrix:
+            return c_vec
+        else:
+            return cls.vec_to_corr_mat(c_vec, n)
+
+    @classmethod
+    def dist(cls, n, eta, *, return_matrix=False, **kwargs):
+        c_vec = _LKJCorr.dist(eta=eta, n=n, **kwargs)
+        if not return_matrix:
+            return c_vec
+        else:
+            return cls.vec_to_corr_mat(c_vec, n)
+
+    @classmethod
+    def vec_to_corr_mat(cls, vec, n):
+        tri = pt.zeros(pt.concatenate([vec.shape[:-1], (n, n)]))
+        tri = pt.subtensor.set_subtensor(tri[(..., *np.triu_indices(n, 1))], vec)
+        return tri + pt.moveaxis(tri, -2, -1) + pt.diag(pt.ones(n))
 
 
 class MatrixNormalRV(RandomVariable):
@@ -1763,6 +1814,7 @@ class MatrixNormal(Continuous):
             vals = pm.MatrixNormal('vals', mu=mu, colchol=colchol, rowcov=rowcov,
                                    observed=data)
     """
+
     rv_op = matrixnormal
 
     @classmethod
@@ -1811,11 +1863,11 @@ class MatrixNormal(Continuous):
 
         # Broadcasting mu
         mu = pt.extra_ops.broadcast_to(mu, shape=dist_shape)
-        mu = pt.as_tensor_variable(floatX(mu))
+        mu = pt.as_tensor_variable(mu)
 
         return super().dist([mu, rowchol_cov, colchol_cov], **kwargs)
 
-    def moment(rv, size, mu, rowchol, colchol):
+    def support_point(rv, size, mu, rowchol, colchol):
         return pt.full_like(rv, mu)
 
     def logp(value, mu, rowchol, colchol):
@@ -1855,7 +1907,7 @@ class MatrixNormal(Continuous):
         m = rowchol.shape[0]
         n = colchol.shape[0]
 
-        norm = -0.5 * m * n * pm.floatX(np.log(2 * np.pi))
+        norm = -0.5 * m * n * np.log(2 * np.pi)
         return norm - 0.5 * trquaddist - m * half_collogdet - n * half_rowlogdet
 
 
@@ -1977,6 +2029,7 @@ class KroneckerNormal(Continuous):
     ----------
     .. [1] Saatchi, Y. (2011). "Scalable inference for structured Gaussian process models"
     """
+
     rv_op = kroneckernormal
 
     @classmethod
@@ -2002,11 +2055,11 @@ class KroneckerNormal(Continuous):
 
         return super().dist([mu, sigma, *covs], **kwargs)
 
-    def moment(rv, size, mu, covs, chols, evds):
+    def support_point(rv, size, mu, covs, chols, evds):
         mean = mu
         if not rv_size_is_none(size):
-            moment_size = pt.concatenate([size, mu.shape])
-            mean = pt.full(moment_size, mu)
+            support_point_size = pt.concatenate([size, mu.shape])
+            mean = pt.full(support_point_size, mu)
         return mean
 
     def logp(value, mu, sigma, *covs):
@@ -2065,13 +2118,13 @@ class CARRV(RandomVariable):
     _print_name = ("CAR", "\\operatorname{CAR}")
 
     def make_node(self, rng, size, dtype, mu, W, alpha, tau):
-        mu = pt.as_tensor_variable(floatX(mu))
+        mu = pt.as_tensor_variable(mu)
 
-        W = pytensor.sparse.as_sparse_or_tensor_variable(floatX(W))
+        W = pytensor.sparse.as_sparse_or_tensor_variable(W)
         if not W.ndim == 2:
             raise ValueError("W must be a matrix (ndim=2).")
 
-        sparse = isinstance(W, pytensor.sparse.SparseVariable)
+        sparse = isinstance(W.type, pytensor.sparse.SparseTensorType)
         msg = "W must be a symmetric adjacency matrix."
         if sparse:
             abs_diff = pytensor.sparse.basic.mul(pytensor.sparse.sign(W - W.T), W - W.T)
@@ -2079,9 +2132,9 @@ class CARRV(RandomVariable):
         else:
             W = Assert(msg)(W, pt.allclose(W, W.T))
 
-        tau = pt.as_tensor_variable(floatX(tau))
+        tau = pt.as_tensor_variable(tau)
 
-        alpha = pt.as_tensor_variable(floatX(alpha))
+        alpha = pt.as_tensor_variable(alpha)
 
         return super().make_node(rng, size, dtype, mu, W, alpha, tau)
 
@@ -2128,7 +2181,7 @@ class CARRV(RandomVariable):
 
         size = tuple(size or ())
         if size:
-            mu = np.broadcast_to(mu, size + (mu.shape[-1],))
+            mu = np.broadcast_to(mu, (*size, mu.shape[-1]))
         z = rng.normal(size=mu.shape)
         samples = np.empty(z.shape)
         for idx in np.ndindex(mu.shape[:-1]):
@@ -2183,13 +2236,14 @@ class CAR(Continuous):
         "Generalized Hierarchical Multivariate CAR Models for Areal Data"
         Biometrics, Vol. 61, No. 4 (Dec., 2005), pp. 950-961
     """
+
     rv_op = car
 
     @classmethod
     def dist(cls, mu, W, alpha, tau, *args, **kwargs):
         return super().dist([mu, W, alpha, tau], **kwargs)
 
-    def moment(rv, size, mu, W, alpha, tau):
+    def support_point(rv, size, mu, W, alpha, tau):
         return pt.full_like(rv, mu)
 
     def logp(value, mu, W, alpha, tau):
@@ -2391,18 +2445,16 @@ class ICAR(Continuous):
         N = pt.shape(W)[0]
         N = pt.as_tensor_variable(N)
 
-        sigma = pt.as_tensor_variable(floatX(sigma))
-        zero_sum_stdev = pt.as_tensor_variable(floatX(zero_sum_stdev))
+        sigma = pt.as_tensor_variable(sigma)
+        zero_sum_stdev = pt.as_tensor_variable(zero_sum_stdev)
 
         return super().dist([W, node1, node2, N, sigma, zero_sum_stdev], **kwargs)
 
-    def moment(rv, size, W, node1, node2, N, sigma, zero_sum_stdev):
+    def support_point(rv, size, W, node1, node2, N, sigma, zero_sum_stdev):
         return pt.zeros(N)
 
     def logp(value, W, node1, node2, N, sigma, zero_sum_stdev):
-        pairwise_difference = (-1 / (2 * sigma**2)) * pt.sum(
-            pt.square(value[node1] - value[node2])
-        )
+        pairwise_difference = (-1 / (2 * sigma**2)) * pt.sum(pt.square(value[node1] - value[node2]))
         zero_sum = (
             -0.5 * pt.pow(pt.sum(value) / (zero_sum_stdev * N), 2)
             - pt.log(pt.sqrt(2.0 * np.pi))
@@ -2438,7 +2490,7 @@ class StickBreakingWeightsRV(RandomVariable):
             raise ValueError("K needs to be positive.")
 
         size = to_tuple(size) if size is not None else alpha.shape
-        size = size + (K,)
+        size = (*size, K)
         alpha = alpha[..., np.newaxis]
 
         betas = rng.beta(1, alpha, size=size)
@@ -2498,22 +2550,23 @@ class StickBreakingWeights(SimplexContinuous):
     .. [2] Müller, P., Quintana, F. A., Jara, A., & Hanson, T. (2015). Bayesian nonparametric data
            analysis. New York: Springer.
     """
+
     rv_op = stickbreakingweights
 
     @classmethod
     def dist(cls, alpha, K, *args, **kwargs):
-        alpha = pt.as_tensor_variable(floatX(alpha))
-        K = pt.as_tensor_variable(intX(K))
+        alpha = pt.as_tensor_variable(alpha)
+        K = pt.as_tensor_variable(K, dtype=int)
 
         return super().dist([alpha, K], **kwargs)
 
-    def moment(rv, size, alpha, K):
+    def support_point(rv, size, alpha, K):
         alpha = alpha[..., np.newaxis]
-        moment = (alpha / (1 + alpha)) ** pt.arange(K)
-        moment *= 1 / (1 + alpha)
-        moment = pt.concatenate([moment, (alpha / (1 + alpha)) ** K], axis=-1)
+        support_point = (alpha / (1 + alpha)) ** pt.arange(K)
+        support_point *= 1 / (1 + alpha)
+        support_point = pt.concatenate([support_point, (alpha / (1 + alpha)) ** K], axis=-1)
         if not rv_size_is_none(size):
-            moment_size = pt.concatenate(
+            support_point_size = pt.concatenate(
                 [
                     size,
                     [
@@ -2521,9 +2574,9 @@ class StickBreakingWeights(SimplexContinuous):
                     ],
                 ]
             )
-            moment = pt.full(moment_size, moment)
+            support_point = pt.full(support_point_size, support_point)
 
-        return moment
+        return support_point
 
     def logp(value, alpha, K):
         """
@@ -2641,6 +2694,7 @@ class ZeroSumNormal(Distribution):
             # the zero sum axes will be the last two
             v = pm.ZeroSumNormal("v", shape=(3, 4, 5), n_zerosum_axes=2)
     """
+
     rv_type = ZeroSumNormalRV
 
     def __new__(
@@ -2676,7 +2730,7 @@ class ZeroSumNormal(Distribution):
     def dist(cls, sigma=1, n_zerosum_axes=None, support_shape=None, **kwargs):
         n_zerosum_axes = cls.check_zerosum_axes(n_zerosum_axes)
 
-        sigma = pt.as_tensor_variable(floatX(sigma))
+        sigma = pt.as_tensor_variable(sigma)
         if not all(sigma.type.broadcastable[-n_zerosum_axes:]):
             raise ValueError("sigma must have length one across the zero-sum axes")
 
@@ -2734,10 +2788,12 @@ class ZeroSumNormal(Distribution):
         for axis in range(n_zerosum_axes):
             zerosum_rv_ -= zerosum_rv_.mean(axis=-axis - 1, keepdims=True)
 
+        support_str = ",".join([f"d{i}" for i in range(n_zerosum_axes)])
+        signature = f"({support_str}),(),(s)->({support_str})"
         return ZeroSumNormalRV(
             inputs=[normal_dist_, sigma_, support_shape_],
-            outputs=[zerosum_rv_, support_shape_],
-            ndim_supp=n_zerosum_axes,
+            outputs=[zerosum_rv_],
+            signature=signature,
         )(normal_dist, sigma, support_shape)
 
 
@@ -2755,8 +2811,8 @@ def change_zerosum_size(op, normal_dist, new_size, expand=False):
     )
 
 
-@_moment.register(ZeroSumNormalRV)
-def zerosumnormal_moment(op, rv, *rv_inputs):
+@_support_point.register(ZeroSumNormalRV)
+def zerosumnormal_support_point(op, rv, *rv_inputs):
     return pt.zeros_like(rv)
 
 
@@ -2774,8 +2830,8 @@ def zerosumnormal_logp(op, values, normal_dist, sigma, support_shape, **kwargs):
     *_, sigma = normal_dist.owner.inputs
 
     _deg_free_support_shape = pt.inc_subtensor(shape[-n_zerosum_axes:], -1)
-    _full_size = pm.floatX(pt.prod(shape))
-    _degrees_of_freedom = pm.floatX(pt.prod(_deg_free_support_shape))
+    _full_size = pt.prod(shape).astype("floatX")
+    _degrees_of_freedom = pt.prod(_deg_free_support_shape).astype("floatX")
 
     zerosums = [
         pt.all(pt.isclose(pt.mean(value, axis=-axis - 1), 0, atol=1e-9))
