@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -17,10 +17,12 @@
 A collection of common shape operations needed for broadcasting
 samples from probability distributions for stochastic nodes in PyMC.
 """
+
 import warnings
 
+from collections.abc import Sequence
 from functools import singledispatch
-from typing import Any, Optional, Sequence, Tuple, Union, cast
+from typing import Any, Optional, Union, cast
 
 import numpy as np
 
@@ -108,6 +110,7 @@ def broadcast_dist_samples_shape(shapes, size=None):
     Examples
     --------
     .. code-block:: python
+
         size = 100
         shape0 = (size,)
         shape1 = (size, 5)
@@ -115,7 +118,9 @@ def broadcast_dist_samples_shape(shapes, size=None):
         out = broadcast_dist_samples_shape([shape0, shape1, shape2],
                                            size=size)
         assert out == (size, 4, 5)
+
     .. code-block:: python
+
         size = 100
         shape0 = (size,)
         shape1 = (5,)
@@ -123,7 +128,9 @@ def broadcast_dist_samples_shape(shapes, size=None):
         out = broadcast_dist_samples_shape([shape0, shape1, shape2],
                                            size=size)
         assert out == (size, 4, 5)
+
     .. code-block:: python
+
         size = 100
         shape0 = (1,)
         shape1 = (5,)
@@ -175,9 +182,9 @@ Dims: TypeAlias = Union[str, Sequence[Optional[str]]]
 Size: TypeAlias = Union[int, TensorVariable, Sequence[Union[int, Variable]]]
 
 # After conversion to vectors
-StrongShape: TypeAlias = Union[TensorVariable, Tuple[Union[int, Variable], ...]]
+StrongShape: TypeAlias = Union[TensorVariable, tuple[Union[int, Variable], ...]]
 StrongDims: TypeAlias = Sequence[Optional[str]]
-StrongSize: TypeAlias = Union[TensorVariable, Tuple[Union[int, Variable], ...]]
+StrongSize: TypeAlias = Union[TensorVariable, tuple[Union[int, Variable], ...]]
 
 
 def convert_dims(dims: Optional[Dims]) -> Optional[StrongDims]:
@@ -419,7 +426,7 @@ def get_support_shape(
     shape: Optional[Shape] = None,
     dims: Optional[Dims] = None,
     observed: Optional[Any] = None,
-    support_shape_offset: Sequence[int] = None,
+    support_shape_offset: Optional[Sequence[int]] = None,
     ndim_supp: int = 1,
 ) -> Optional[TensorVariable]:
     """Extract the support shapes from shape / dims / observed information
