@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -16,9 +16,10 @@ import numbers
 import warnings
 
 from collections import Counter
+from collections.abc import Sequence
 from functools import reduce
 from operator import add, mul
-from typing import Any, Callable, List, Optional, Sequence, Union
+from typing import Any, Callable, Optional, Union
 
 import numpy as np
 import pytensor.tensor as pt
@@ -179,14 +180,15 @@ class Covariance(BaseCovariance):
         """The dimensionality of the input, as taken from the
         `active_dims`.
         """
-        # Evaluate lazily in-case this changes.
+        # Evaluate lazily in case this changes.
         return len(self.active_dims)
 
     def _slice(self, X, Xs=None):
         xdims = X.shape[-1]
         if isinstance(xdims, Variable):
-            [xdims] = constant_fold([xdims])
-        if self.input_dim != xdims:
+            [xdims] = constant_fold([xdims], raise_not_constant=False)
+        # If xdims can't be fully constant folded, it will be a TensorVariable
+        if isinstance(xdims, int) and self.input_dim != xdims:
             warnings.warn(
                 f"Only {self.input_dim} column(s) out of {xdims} are"
                 " being used to compute the covariance function. If this"
@@ -229,7 +231,7 @@ class Combination(Covariance):
         super().__init__(input_dim=input_dim, active_dims=active_dims)
 
         # Set up combination kernel, flatten out factor_list so that
-        self._factor_list: List[Any] = []
+        self._factor_list: list[Any] = []
         for factor in factor_list:
             if isinstance(factor, self.__class__):
                 self._factor_list.extend(factor._factor_list)
