@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,7 +14,8 @@
 import functools
 import warnings
 
-from typing import Callable, Dict, List, Optional, Sequence, Set, Union
+from collections.abc import Sequence
+from typing import Callable, Optional, Union
 
 import numpy as np
 import pytensor
@@ -28,13 +29,13 @@ from pymc.logprob.transforms import Transform
 from pymc.pytensorf import compile_pymc, find_rng_nodes, replace_rng_nodes, reseed_rngs
 from pymc.util import get_transformed_name, get_untransformed_name, is_transformed_name
 
-StartDict = Dict[Union[Variable, str], Union[np.ndarray, Variable, str]]
-PointType = Dict[str, np.ndarray]
+StartDict = dict[Union[Variable, str], Union[np.ndarray, Variable, str]]
+PointType = dict[str, np.ndarray]
 
 
 def convert_str_to_rv_dict(
     model, start: StartDict
-) -> Dict[TensorVariable, Optional[Union[np.ndarray, Variable, str]]]:
+) -> dict[TensorVariable, Optional[Union[np.ndarray, Variable, str]]]:
     """Helper function for converting a user-provided start dict with str keys of (transformed) variable names
     to a dict mapping the RV tensors to untransformed initvals.
     TODO: Deprecate this functionality and only accept TensorVariables as keys
@@ -56,9 +57,9 @@ def make_initial_point_fns_per_chain(
     *,
     model,
     overrides: Optional[Union[StartDict, Sequence[Optional[StartDict]]]],
-    jitter_rvs: Optional[Set[TensorVariable]] = None,
+    jitter_rvs: Optional[set[TensorVariable]] = None,
     chains: int,
-) -> List[Callable]:
+) -> list[Callable]:
     """Create an initial point function for each chain, as defined by initvals
 
     If a single initval dictionary is passed, the function is replicated for each
@@ -112,8 +113,8 @@ def make_initial_point_fn(
     *,
     model,
     overrides: Optional[StartDict] = None,
-    jitter_rvs: Optional[Set[TensorVariable]] = None,
-    default_strategy: str = "moment",
+    jitter_rvs: Optional[set[TensorVariable]] = None,
+    default_strategy: str = "support_point",
     return_transformed: bool = True,
 ) -> Callable:
     """Create seeded function that computes initial values for all free model variables.
@@ -124,7 +125,7 @@ def make_initial_point_fn(
         The set (or list or tuple) of random variables for which a U(-1, +1) jitter should be
         added to the initial value. Only available for variables that have a transform or real-valued support.
     default_strategy : str
-        Which of { "moment", "prior" } to prefer if the initval setting for an RV is None.
+        Which of { "support_point", "prior" } to prefer if the initval setting for an RV is None.
     overrides : dict
         Initial value (strategies) to use instead of what's specified in `Model.initial_values`.
     return_transformed : bool
@@ -177,12 +178,12 @@ def make_initial_point_fn(
 def make_initial_point_expression(
     *,
     free_rvs: Sequence[TensorVariable],
-    rvs_to_transforms: Dict[TensorVariable, Transform],
-    initval_strategies: Dict[TensorVariable, Optional[Union[np.ndarray, Variable, str]]],
-    jitter_rvs: Set[TensorVariable] = None,
-    default_strategy: str = "moment",
+    rvs_to_transforms: dict[TensorVariable, Transform],
+    initval_strategies: dict[TensorVariable, Optional[Union[np.ndarray, Variable, str]]],
+    jitter_rvs: Optional[set[TensorVariable]] = None,
+    default_strategy: str = "support_point",
     return_transformed: bool = False,
-) -> List[TensorVariable]:
+) -> list[TensorVariable]:
     """Creates the tensor variables that need to be evaluated to obtain an initial point.
 
     Parameters
@@ -198,7 +199,7 @@ def make_initial_point_expression(
         The set (or list or tuple) of random variables for which a U(-1, +1) jitter should be
         added to the initial value. Only available for variables that have a transform or real-valued support.
     default_strategy : str
-        Which of { "moment", "prior" } to prefer if the initval strategy setting for an RV is None.
+        Which of { "support_point", "prior" } to prefer if the initval strategy setting for an RV is None.
     return_transformed : bool
         Switches between returning the tensors for untransformed or transformed initial points.
 
@@ -207,7 +208,7 @@ def make_initial_point_expression(
     initial_points : list of TensorVariable
         PyTensor expressions for initial values of the free random variables.
     """
-    from pymc.distributions.distribution import moment
+    from pymc.distributions.distribution import support_point
 
     if jitter_rvs is None:
         jitter_rvs = set()
@@ -223,15 +224,21 @@ def make_initial_point_expression(
 
         if isinstance(strategy, str):
             if strategy == "moment":
+                strategy = "support_point"
+                warnings.warn(
+                    "The 'moment' strategy is deprecated. Use 'support_point' instead.",
+                    FutureWarning,
+                )
+            if strategy == "support_point":
                 try:
-                    value = moment(variable)
+                    value = support_point(variable)
                 except NotImplementedError:
                     warnings.warn(
                         f"Moment not defined for variable {variable} of type "
                         f"{variable.owner.op.__class__.__name__}, defaulting to "
                         f"a draw from the prior. This can lead to difficulties "
                         f"during tuning. You can manually define an initval or "
-                        f"implement a moment dispatched function for this "
+                        f"implement a support_point dispatched function for this "
                         f"distribution.",
                         UserWarning,
                     )
@@ -240,7 +247,7 @@ def make_initial_point_expression(
                 value = variable
             else:
                 raise ValueError(
-                    f'Invalid string strategy: {strategy}. It must be one of ["moment", "prior"]'
+                    f'Invalid string strategy: {strategy}. It must be one of ["support_point", "prior"]'
                 )
         else:
             value = pt.as_tensor(strategy, dtype=variable.dtype).astype(variable.dtype)
@@ -263,7 +270,7 @@ def make_initial_point_expression(
 
         initial_values.append(value)
 
-    all_outputs: List[TensorVariable] = []
+    all_outputs: list[TensorVariable] = []
     all_outputs.extend(free_rvs)
     all_outputs.extend(initial_values)
     all_outputs.extend(initial_values_transformed)
