@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -34,13 +34,14 @@
 #   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #   SOFTWARE.
 
-from typing import List, Optional, Union
+from typing import Optional, Union
 
 import pytensor
 
 from pytensor import tensor as pt
 from pytensor.graph.op import compute_test_value
 from pytensor.graph.rewriting.basic import node_rewriter
+from pytensor.tensor import TensorVariable
 from pytensor.tensor.basic import Alloc, Join, MakeVector
 from pytensor.tensor.elemwise import DimShuffle
 from pytensor.tensor.random.op import RandomVariable
@@ -197,9 +198,7 @@ def logprob_join(op, values, axis, *base_rvs, **kwargs):
 
 
 @node_rewriter([MakeVector, Join])
-def find_measurable_stacks(
-    fgraph, node
-) -> Optional[List[Union[MeasurableMakeVector, MeasurableJoin]]]:
+def find_measurable_stacks(fgraph, node) -> Optional[list[TensorVariable]]:
     r"""Finds `Joins`\s and `MakeVector`\s for which a `logprob` can be computed."""
 
     rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
@@ -248,7 +247,7 @@ def logprob_dimshuffle(op, values, base_var, **kwargs):
 
     # Reverse the effects of dimshuffle on the value variable
     # First, drop any augmented dimensions and reinsert any dropped dimensions
-    undo_ds: List[Union[int, str]] = [i for i, o in enumerate(op.new_order) if o != "x"]
+    undo_ds: list[Union[int, str]] = [i for i, o in enumerate(op.new_order) if o != "x"]
     dropped_dims = tuple(sorted(set(op.transposition) - set(op.shuffle)))
     for dropped_dim in dropped_dims:
         undo_ds.insert(dropped_dim, "x")
@@ -273,7 +272,7 @@ def logprob_dimshuffle(op, values, base_var, **kwargs):
 
 
 @node_rewriter([DimShuffle])
-def find_measurable_dimshuffles(fgraph, node) -> Optional[List[MeasurableDimShuffle]]:
+def find_measurable_dimshuffles(fgraph, node) -> Optional[list[TensorVariable]]:
     r"""Finds `Dimshuffle`\s for which a `logprob` can be computed."""
 
     rv_map_feature: Optional[PreserveRVMappings] = getattr(fgraph, "preserve_rv_mappings", None)
