@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@
 #   SOFTWARE.
 import abc
 
-from typing import Callable, List, Optional, Tuple, Union
+from typing import Callable, Optional, Union
 
 import numpy as np
 import pytensor.tensor as pt
@@ -117,7 +117,11 @@ from pymc.logprob.abstract import (
     _logprob_helper,
 )
 from pymc.logprob.rewriting import PreserveRVMappings, measurable_ir_rewrites_db
-from pymc.logprob.utils import CheckParameterValue, check_potential_measurability
+from pymc.logprob.utils import (
+    CheckParameterValue,
+    check_potential_measurability,
+    find_negated_var,
+)
 
 
 class Transform(abc.ABC):
@@ -130,7 +134,7 @@ class Transform(abc.ABC):
     @abc.abstractmethod
     def backward(
         self, value: TensorVariable, *inputs: Variable
-    ) -> Union[TensorVariable, Tuple[TensorVariable, ...]]:
+    ) -> Union[TensorVariable, tuple[TensorVariable, ...]]:
         """Invert the transformation. Multiple values may be returned when the
         transformation is not 1-to-1"""
 
@@ -229,6 +233,10 @@ def measurable_transform_logcdf(op: MeasurableTransform, value, *inputs, **kwarg
     other_inputs = list(inputs)
     measurable_input = other_inputs.pop(op.measurable_input_idx)
 
+    # Do not apply rewrite to discrete variables
+    if measurable_input.type.dtype.startswith("int"):
+        raise NotImplementedError("logcdf of transformed discrete variables not implemented")
+
     backward_value = op.transform_elemwise.backward(value, *other_inputs)
 
     # Fail if transformation is not injective
@@ -273,6 +281,10 @@ def measurable_transform_icdf(op: MeasurableTransform, value, *inputs, **kwargs)
     other_inputs = list(inputs)
     measurable_input = other_inputs.pop(op.measurable_input_idx)
 
+    # Do not apply rewrite to discrete variables
+    if measurable_input.type.dtype.startswith("int"):
+        raise NotImplementedError("icdf of transformed discrete variables not implemented")
+
     if isinstance(op.scalar_op, MONOTONICALLY_INCREASING_OPS):
         pass
     elif isinstance(op.scalar_op, MONOTONICALLY_DECREASING_OPS):
@@ -411,7 +423,7 @@ def measurable_power_exponent_to_exp(fgraph, node):
         erfcx,
     ]
 )
-def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[List[Node]]:
+def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[list[Node]]:
     """Find measurable transformations from Elemwise operators."""
 
     # Node was already converted
@@ -429,10 +441,15 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
         return None
 
     [measurable_input] = measurable_inputs
+    [measurable_output] = node.outputs
 
-    # Do not apply rewrite to discrete variables
+    # Do not apply rewrite to discrete variables except for their addition and negation
     if measurable_input.type.dtype.startswith("int"):
-        return None
+        if not (find_negated_var(measurable_output) or isinstance(node.op.scalar_op, Add)):
+            return None
+        # Do not allow rewrite if output is cast to a float, because we don't have meta-info on the type of the MeasurableVariable
+        if not measurable_output.type.dtype.startswith("int"):
+            return None
 
     # Check that other inputs are not potentially measurable, in which case this rewrite
     # would be invalid
@@ -443,7 +460,7 @@ def find_measurable_transforms(fgraph: FunctionGraph, node: Node) -> Optional[Li
 
     scalar_op = node.op.scalar_op
     measurable_input_idx = 0
-    transform_inputs: Tuple[TensorVariable, ...] = (measurable_input,)
+    transform_inputs: tuple[TensorVariable, ...] = (measurable_input,)
     transform: Transform
 
     transform_dict = {
@@ -804,7 +821,7 @@ class PowerTransform(Transform):
 class IntervalTransform(Transform):
     name = "interval"
 
-    def __init__(self, args_fn: Callable[..., Tuple[Optional[Variable], Optional[Variable]]]):
+    def __init__(self, args_fn: Callable[..., tuple[Optional[Variable], Optional[Variable]]]):
         """
 
         Parameters
