@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@
 import typing
 import warnings
 
-from typing import Container, Dict, List, Optional, Sequence, Set, Tuple, Union
+from collections.abc import Container, Sequence
+from typing import Optional, Union
 
 import numpy as np
 import pytensor
@@ -48,6 +49,10 @@ from pytensor.graph.basic import Constant, clone_get_equiv, graph_inputs, walk
 from pytensor.graph.op import HasInnerGraph
 from pytensor.link.c.type import CType
 from pytensor.raise_op import CheckAndRaise
+from pytensor.scalar.basic import Mul
+from pytensor.tensor.basic import get_underlying_scalar_constant_value
+from pytensor.tensor.elemwise import Elemwise
+from pytensor.tensor.exceptions import NotScalarConstantError
 from pytensor.tensor.random.op import RandomVariable
 from pytensor.tensor.variable import TensorVariable
 
@@ -62,9 +67,9 @@ if typing.TYPE_CHECKING:
 def replace_rvs_by_values(
     graphs: Sequence[TensorVariable],
     *,
-    rvs_to_values: Dict[TensorVariable, TensorVariable],
-    rvs_to_transforms: Optional[Dict[TensorVariable, "Transform"]] = None,
-) -> List[TensorVariable]:
+    rvs_to_values: dict[TensorVariable, TensorVariable],
+    rvs_to_transforms: Optional[dict[TensorVariable, "Transform"]] = None,
+) -> list[TensorVariable]:
     """Clone and replace random variables in graphs with their value variables.
 
     Parameters
@@ -127,7 +132,7 @@ def replace_rvs_by_values(
     return replace_vars_in_graphs(graphs, replacements)
 
 
-def rvs_in_graph(vars: Union[Variable, Sequence[Variable]]) -> Set[Variable]:
+def rvs_in_graph(vars: Union[Variable, Sequence[Variable]]) -> set[Variable]:
     """Assert that there are no `MeasurableVariable` nodes in a graph."""
 
     def expand(r):
@@ -169,7 +174,7 @@ def indices_from_subtensor(idx_list, indices):
 
 
 def check_potential_measurability(
-    inputs: Tuple[TensorVariable], valued_rvs: Container[TensorVariable]
+    inputs: tuple[TensorVariable], valued_rvs: Container[TensorVariable]
 ) -> bool:
     valued_rvs = set(valued_rvs)
 
@@ -295,3 +300,26 @@ def diracdelta_logprob(op, values, *inputs, **kwargs):
     (const_value,) = inputs
     values, const_value = pt.broadcast_arrays(values, const_value)
     return pt.switch(pt.isclose(values, const_value, rtol=op.rtol, atol=op.atol), 0.0, -np.inf)
+
+
+def find_negated_var(var):
+    """Return a variable that is being multiplied by -1 or None otherwise."""
+
+    if (
+        not (var.owner)
+        and isinstance(var.owner.op, Elemwise)
+        and isinstance(var.owner.op.scalar_op, Mul)
+    ):
+        return None
+    if len(var.owner.inputs) != 2:
+        return None
+
+    inputs = var.owner.inputs
+    for mul_var, mul_const in (inputs, reversed(inputs)):
+        try:
+            if get_underlying_scalar_constant_value(mul_const) == -1:
+                return mul_var
+        except NotScalarConstantError:
+            continue
+
+    return None
