@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -18,19 +18,14 @@ import threading
 import types
 import warnings
 
+from collections.abc import Iterable, Sequence
 from sys import modules
 from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
-    Dict,
-    Iterable,
-    List,
     Literal,
     Optional,
-    Sequence,
-    Tuple,
-    Type,
     TypeVar,
     Union,
     cast,
@@ -49,7 +44,6 @@ from pytensor.scalar import Cast
 from pytensor.tensor.elemwise import Elemwise
 from pytensor.tensor.random.op import RandomVariable
 from pytensor.tensor.random.type import RandomType
-from pytensor.tensor.sharedvar import ScalarSharedVariable
 from pytensor.tensor.variable import TensorConstant, TensorVariable
 from typing_extensions import Self
 
@@ -109,7 +103,7 @@ class ContextMeta(type):
     the `with` statement.
     """
 
-    def __new__(cls, name, bases, dct, **kwargs):  # pylint: disable=unused-argument
+    def __new__(cls, name, bases, dct, **kwargs):
         """Add __enter__ and __exit__ methods to the class."""
 
         def __enter__(self):
@@ -121,7 +115,7 @@ class ContextMeta(type):
                 self._config_context.__enter__()
             return self
 
-        def __exit__(self, typ, value, traceback):  # pylint: disable=unused-argument
+        def __exit__(self, typ, value, traceback):
             self.__class__.context_class.get_contexts().pop()
             # self._pytensor_config is set in Model.__new__
             if self._config_context:
@@ -138,9 +132,7 @@ class ContextMeta(type):
 
     # FIXME: is there a more elegant way to automatically add methods to the class that
     # are instance methods instead of class methods?
-    def __init__(
-        cls, name, bases, nmspc, context_class: Optional[Type] = None, **kwargs
-    ):  # pylint: disable=unused-argument
+    def __init__(cls, name, bases, nmspc, context_class: Optional[type] = None, **kwargs):
         """Add ``__enter__`` and ``__exit__`` methods to the new class automatically."""
         if context_class is not None:
             cls._context_class = context_class
@@ -162,7 +154,7 @@ class ContextMeta(type):
             raise BlockModelAccessError(candidate.error_msg_on_access)
         return candidate
 
-    def get_contexts(cls) -> List[T]:
+    def get_contexts(cls) -> list[T]:
         """Return a stack of context instances for the ``context_class``
         of ``cls``."""
         # This lazily creates the context class's contexts
@@ -191,8 +183,8 @@ class ContextMeta(type):
     # specified, so the context_class may be a class *name* rather
     # than a class.
     @property
-    def context_class(cls) -> Type:
-        def resolve_type(c: Union[Type, str]) -> Type:
+    def context_class(cls) -> type:
+        def resolve_type(c: Union[type, str]) -> type:
             if isinstance(c, str):
                 c = getattr(modules[cls.__module__], c)
             if isinstance(c, type):
@@ -341,7 +333,7 @@ class ValueGradFunction:
             grads = pytensor.grad(cost, grad_vars, disconnected_inputs="ignore")
             for grad_wrt, var in zip(grads, grad_vars):
                 grad_wrt.name = f"{var.name}_grad"
-            outputs = [cost] + grads
+            outputs = [cost, *grads]
         else:
             outputs = [cost]
 
@@ -406,10 +398,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
     Parameters
     ----------
-    name: str
+    name : str
         name that will be used as prefix for names of all random
         variables defined within model
-    check_bounds: bool
+    check_bounds : bool
         Ensure that input parameters to distributions are in a valid
         range. If your model is built in a way where you know your
         parameters can only take on valid values you can set this to
@@ -483,11 +475,9 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
     if TYPE_CHECKING:
 
-        def __enter__(self: Self) -> Self:
-            ...
+        def __enter__(self: Self) -> Self: ...
 
-        def __exit__(self, exc_type: None, exc_val: None, exc_tb: None) -> None:
-            ...
+        def __exit__(self, exc_type: None, exc_val: None, exc_tb: None) -> None: ...
 
     def __new__(cls, *args, **kwargs):
         # resolves the parent instance
@@ -588,10 +578,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        grad_vars: list of random variables, optional
+        grad_vars : list of random variables, optional
             Compute the gradient with respect to those variables. If None,
             use all free random variables of this model.
-        tempered: bool
+        tempered : bool
             Compute the tempered logp `free_logp + alpha * observed_logp`.
             `alpha` can be changed using `ValueGradFunction.set_weights([alpha])`.
         """
@@ -627,12 +617,12 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        vars: list of random variables or potential terms, optional
+        vars : list of random variables or potential terms, optional
             Compute the gradient with respect to those variables. If None, use all
             free and observed random variables, as well as potential terms in model.
-        jacobian:
+        jacobian : bool
             Whether to include jacobian terms in logprob graph. Defaults to True.
-        sum:
+        sum : bool
             Whether to sum all logp terms or return elemwise logp for each variable.
             Defaults to True.
         """
@@ -647,10 +637,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        vars: list of random variables or potential terms, optional
+        vars : list of random variables or potential terms, optional
             Compute the gradient with respect to those variables. If None, use all
             free and observed random variables, as well as potential terms in model.
-        jacobian:
+        jacobian : bool
             Whether to include jacobian terms in logprob graph. Defaults to True.
         """
         return self.compile_fn(self.dlogp(vars=vars, jacobian=jacobian))
@@ -664,10 +654,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        vars: list of random variables or potential terms, optional
+        vars : list of random variables or potential terms, optional
             Compute the gradient with respect to those variables. If None, use all
             free and observed random variables, as well as potential terms in model.
-        jacobian:
+        jacobian : bool
             Whether to include jacobian terms in logprob graph. Defaults to True.
         """
         return self.compile_fn(self.d2logp(vars=vars, jacobian=jacobian))
@@ -677,17 +667,17 @@ class Model(WithMemoization, metaclass=ContextMeta):
         vars: Optional[Union[Variable, Sequence[Variable]]] = None,
         jacobian: bool = True,
         sum: bool = True,
-    ) -> Union[Variable, List[Variable]]:
+    ) -> Union[Variable, list[Variable]]:
         """Elemwise log-probability of the model.
 
         Parameters
         ----------
-        vars: list of random variables or potential terms, optional
+        vars : list of random variables or potential terms, optional
             Compute the gradient with respect to those variables. If None, use all
             free and observed random variables, as well as potential terms in model.
-        jacobian:
+        jacobian : bool
             Whether to include jacobian terms in logprob graph. Defaults to True.
-        sum:
+        sum : bool
             Whether to sum all logp terms or return elemwise logp for each variable.
             Defaults to True.
 
@@ -695,13 +685,13 @@ class Model(WithMemoization, metaclass=ContextMeta):
         -------
         Logp graph(s)
         """
-        varlist: List[TensorVariable]
+        varlist: list[TensorVariable]
         if vars is None:
             varlist = self.free_RVs + self.observed_RVs + self.potentials
         elif not isinstance(vars, (list, tuple)):
             varlist = [vars]
         else:
-            varlist = cast(List[TensorVariable], vars)
+            varlist = cast(list[TensorVariable], vars)
 
         # We need to separate random variables from potential terms, and remember their
         # original order so that we can merge them together in the same order at the end
@@ -722,7 +712,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
                         f"Requested variable {var} not found among the model variables"
                     )
 
-        rv_logps: List[TensorVariable] = []
+        rv_logps: list[TensorVariable] = []
         if rvs:
             rv_logps = transformed_conditional_logp(
                 rvs=rvs,
@@ -760,10 +750,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        vars: list of random variables or potential terms, optional
+        vars : list of random variables or potential terms, optional
             Compute the gradient with respect to those variables. If None, use all
             free and observed random variables, as well as potential terms in model.
-        jacobian:
+        jacobian : bool
             Whether to include jacobian terms in logprob graph. Defaults to True.
 
         Returns
@@ -799,10 +789,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        vars: list of random variables or potential terms, optional
+        vars : list of random variables or potential terms, optional
             Compute the gradient with respect to those variables. If None, use all
             free and observed random variables, as well as potential terms in model.
-        jacobian:
+        jacobian : bool
             Whether to include jacobian terms in logprob graph. Defaults to True.
 
         Returns
@@ -927,12 +917,12 @@ class Model(WithMemoization, metaclass=ContextMeta):
         return self.free_RVs + self.deterministics
 
     @property
-    def coords(self) -> Dict[str, Union[Tuple, None]]:
+    def coords(self) -> dict[str, Union[tuple, None]]:
         """Coordinate values for model dimensions."""
         return self._coords
 
     @property
-    def dim_lengths(self) -> Dict[str, Variable]:
+    def dim_lengths(self) -> dict[str, Variable]:
         """The symbolic lengths of dimensions in the model.
 
         The values are typically instances of ``TensorVariable`` or ``ScalarSharedVariable``.
@@ -969,7 +959,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
         name : str
             Name of the dimension.
             Forbidden: {"chain", "draw", "__sample__"}
-        values : optional, array-like
+        values : optional, array_like
             Coordinate values or ``None`` (for auto-numbering).
             If ``None`` is passed, a ``length`` must be specified.
         mutable : bool
@@ -1006,14 +996,15 @@ class Model(WithMemoization, metaclass=ContextMeta):
                 length = pytensor.shared(length, name=name)
             else:
                 length = pytensor.tensor.constant(length)
+        assert length.type.ndim == 0
         self._dim_lengths[name] = length
         self._coords[name] = values
 
     def add_coords(
         self,
-        coords: Dict[str, Optional[Sequence]],
+        coords: dict[str, Optional[Sequence]],
         *,
-        lengths: Optional[Dict[str, Optional[Union[int, Variable]]]] = None,
+        lengths: Optional[dict[str, Optional[Union[int, Variable]]]] = None,
     ):
         """Vectorized version of ``Model.add_coord``."""
         if coords is None:
@@ -1028,14 +1019,14 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        name
+        name : str
             Name of the dimension.
-        new_length
+        new_length : int
             New length of the dimension.
-        coord_values
+        coord_values : array_like, optional
             Optional sequence of coordinate values.
         """
-        if not isinstance(self.dim_lengths[name], ScalarSharedVariable):
+        if not isinstance(self.dim_lengths[name], SharedVariable):
             raise ValueError(f"The dimension '{name}' is immutable.")
         if coord_values is None and self.coords.get(name, None) is not None:
             raise ValueError(
@@ -1053,7 +1044,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
         self.dim_lengths[name].set_value(new_length)
         return
 
-    def initial_point(self, random_seed: SeedSequenceSeed = None) -> Dict[str, np.ndarray]:
+    def initial_point(self, random_seed: SeedSequenceSeed = None) -> dict[str, np.ndarray]:
         """Computes the initial point of the model.
 
         Parameters
@@ -1081,7 +1072,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
         self,
         name: str,
         values: Union[Sequence, np.ndarray],
-        coords: Optional[Dict[str, Sequence]] = None,
+        coords: Optional[dict[str, Sequence]] = None,
     ):
         """Changes the values of a data variable in the model.
 
@@ -1092,7 +1083,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
         ----------
         name : str
             Name of a shared variable in the model.
-        values : array-like
+        values : array_like
             New values for the shared variable.
         coords : optional, dict
             New coordinate values for dimensions of the shared variable.
@@ -1195,7 +1186,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
                             actual=new_length,
                             expected=old_length,
                         )
-                if isinstance(length_tensor, ScalarSharedVariable):
+                if isinstance(length_tensor, SharedVariable):
                     # The dimension is mutable, but was defined without being linked
                     # to a shared variable. This is allowed, but a little less robust.
                     self.set_dim(dname, new_length, coord_values=new_coords)
@@ -1220,14 +1211,14 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        rv_var: TensorVariable
-        name: str
+        rv_var : TensorVariable
+        name : str
             Intended name for the model variable.
-        observed: array_like (optional)
+        observed : array_like, optional
             Data values for observed variables.
-        total_size: scalar
+        total_size : scalar
             upscales logp of variable with ``coef = total_size/var.shape[0]``
-        dims: tuple
+        dims : tuple
             Dimension names for the variable.
         transform
             A transform for the random variable in log-likelihood space.
@@ -1294,16 +1285,19 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        rv_var
+        rv_var : TensorVariable
             The random variable that is observed.
             Its dimensionality must be compatible with the data already.
-        data
+        data : array_like
             The observed data.
-        dims: tuple
+        dims : tuple
             Dimension names for the variable.
-        transform
+        transform : int, optional
             A transform for the random variable in log-likelihood space.
 
+        Returns
+        -------
+        TensorVariable
         """
         name = rv_var.name
         data = convert_observed_data(data).astype(rv_var.dtype)
@@ -1378,6 +1372,17 @@ class Model(WithMemoization, metaclass=ContextMeta):
         observed data. That's why value variables are only referenced in
         this branch of the conditional.
 
+        Parameters
+        ----------
+        rv_var : TensorVariable
+
+        transform : Any
+
+        value_var : Variable, optional
+
+        Returns
+        -------
+        TensorVariable
         """
 
         # Make the value variable a transformed value variable,
@@ -1416,11 +1421,18 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         return value_var
 
-    def add_named_variable(self, var, dims: Optional[Tuple[Union[str, None], ...]] = None):
+    def add_named_variable(self, var, dims: Optional[tuple[Union[str, None], ...]] = None):
         """Add a random graph variable to the named variables of the model.
 
         This can include several types of variables such basic_RVs, Data, Deterministics,
         and Potentials.
+
+        Parameters
+        ----------
+        var
+
+        dims : tuple, optional
+
         """
         if var.name is None:
             raise ValueError("Variable is unnamed.")
@@ -1486,15 +1498,19 @@ class Model(WithMemoization, metaclass=ContextMeta):
         self,
         graphs: Sequence[TensorVariable],
         **kwargs,
-    ) -> List[TensorVariable]:
+    ) -> list[TensorVariable]:
         """Clone and replace random variables in graphs with their value variables.
 
         This will *not* recompute test values in the resulting graphs.
 
         Parameters
         ----------
-        graphs
+        graphs : array_like
             The graphs in which to perform the replacements.
+
+        Returns
+        -------
+        array_like
         """
         return replace_rvs_by_values(
             graphs,
@@ -1515,9 +1531,9 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        outs
+        outs : Variable or sequence of Variables
             PyTensor variable or iterable of PyTensor variables.
-        inputs
+        inputs : sequence of Variables, optional
             PyTensor input variables, defaults to pytensorf.inputvars(outs).
         mode
             PyTensor compilation mode, default=None.
@@ -1552,12 +1568,12 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        outs: PyTensor variable or iterable of PyTensor variables
-        n: int, default 1000
+        outs : PyTensor variable or iterable of PyTensor variables
+        n : int, default 1000
             Number of iterations to run
-        point: point
+        point : Point
             Point to pass to the function
-        profile: True or ProfileStats
+        profile : True or ProfileStats
         args, kwargs
             Compilation args
 
@@ -1576,19 +1592,24 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         return f.profile
 
-    def update_start_vals(self, a: Dict[str, np.ndarray], b: Dict[str, np.ndarray]):
+    def update_start_vals(self, a: dict[str, np.ndarray], b: dict[str, np.ndarray]):
         r"""Update point `a` with `b`, without overwriting existing keys.
 
         Values specified for transformed variables in `a` will be recomputed
         conditional on the values of `b` and stored in `b`.
 
+        Parameters
+        ----------
+        a : dict
+
+        b : dict
         """
         raise FutureWarning(
             "The `Model.update_start_vals` method was removed."
             " To change initial values you may set the items of `Model.initial_values` directly."
         )
 
-    def eval_rv_shapes(self) -> Dict[str, Tuple[int, ...]]:
+    def eval_rv_shapes(self) -> dict[str, tuple[int, ...]]:
         """Evaluates shapes of untransformed AND transformed free variables.
 
         Returns
@@ -1669,10 +1690,10 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        point: Point, optional
+        point : Point, optional
             Point to be evaluated.  If ``None``, then ``model.initial_point``
             is used.
-        round_vals: int, default 2
+        round_vals : int, default 2
             Number of decimals to round log-probabilities.
 
         Returns
@@ -1695,7 +1716,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
     def debug(
         self,
-        point: Optional[Dict[str, np.ndarray]] = None,
+        point: Optional[dict[str, np.ndarray]] = None,
         fn: Literal["logp", "dlogp", "random"] = "logp",
         verbose: bool = False,
     ):
@@ -1711,7 +1732,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
 
         Parameters
         ----------
-        point : Point
+        point : Point, optional
             Point at which model function should be evaluated
         fn : str, default "logp"
             Function to be used for debugging. Can be one of [logp, dlogp, random].
@@ -1740,7 +1761,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
             done = {}
             used_ids = {}
             for i, out in enumerate(rv_inputs.maker.fgraph.outputs):
-                print_(f"{i}: ", end=""),
+                print_(f"{i}: ", end="")
                 # Don't print useless deepcopys
                 if out.owner and isinstance(out.owner.op, DeepCopyOp):
                     out = out.owner.inputs[0]
@@ -1840,7 +1861,13 @@ class Model(WithMemoization, metaclass=ContextMeta):
             print_("You can set `verbose=True` for more details")
 
     def to_graphviz(
-        self, *, var_names: Optional[Iterable[VarName]] = None, formatting: str = "plain"
+        self,
+        *,
+        var_names: Optional[Iterable[VarName]] = None,
+        formatting: str = "plain",
+        save: Optional[str] = None,
+        figsize: Optional[tuple[int, int]] = None,
+        dpi: int = 300,
     ):
         """Produce a graphviz Digraph from a PyMC model.
 
@@ -1858,6 +1885,14 @@ class Model(WithMemoization, metaclass=ContextMeta):
             Subset of variables to be plotted that identify a subgraph with respect to the entire model graph
         formatting : str, optional
             one of { "plain" }
+        save : str, optional
+            If provided, an image of the graph will be saved to this location. The format is inferred from
+            the file extension.
+        figsize : tuple[int, int], optional
+            Width and height of the figure in inches. If not provided, uses the default figure size. It only affect
+            the size of the saved figure.
+        dpi : int, optional
+            Dots per inch. It only affects the resolution of the saved figure. The default is 300.
 
         Examples
         --------
@@ -1866,7 +1901,7 @@ class Model(WithMemoization, metaclass=ContextMeta):
         .. code-block:: python
 
             import numpy as np
-            from pymc import HalfCauchy, Model, Normal, model_to_graphviz
+            from pymc import HalfCauchy, Model, Normal
 
             J = 8
             y = np.array([28, 8, -3, 7, -1, 1, 18, 12])
@@ -1883,8 +1918,24 @@ class Model(WithMemoization, metaclass=ContextMeta):
                 obs = Normal("obs", theta, sigma=sigma, observed=y)
 
             schools.to_graphviz()
+
+        Note that this code automatically plots the graph if executed in a Jupyter notebook.
+        If executed non-interactively, such as in a script or python console, the graph
+        needs to be rendered explicitly:
+
+        .. code-block:: python
+
+            # creates the file `schools.pdf`
+            schools.to_graphviz().render("schools")
         """
-        return model_to_graphviz(model=self, var_names=var_names, formatting=formatting)
+        return model_to_graphviz(
+            model=self,
+            var_names=var_names,
+            formatting=formatting,
+            save=save,
+            figsize=figsize,
+            dpi=dpi,
+        )
 
 
 # this is really disgusting, but it breaks a self-loop: I can't pass Model
@@ -2019,7 +2070,7 @@ def compile_fn(
     )
 
 
-def Point(*args, filter_model_vars=False, **kwargs) -> Dict[VarName, np.ndarray]:
+def Point(*args, filter_model_vars=False, **kwargs) -> dict[VarName, np.ndarray]:
     """Build a point. Uses same args as dict() does.
     Filters out variables not in the model. All keys are strings.
 
