@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,7 +14,9 @@
 import warnings
 
 from collections import defaultdict
-from typing import Dict, Iterable, List, Optional, Sequence, Set
+from collections.abc import Iterable, Sequence
+from os import path
+from typing import Optional
 
 from pytensor import function
 from pytensor.compile.sharedvalue import SharedVariable
@@ -47,7 +49,7 @@ class ModelGraph:
         self._all_var_names = get_default_varnames(self.model.named_vars, include_transformed=False)
         self.var_list = self.model.named_vars.values()
 
-    def get_parent_names(self, var: TensorVariable) -> Set[VarName]:
+    def get_parent_names(self, var: TensorVariable) -> set[VarName]:
         if var.owner is None or var.owner.inputs is None:
             return set()
 
@@ -82,7 +84,7 @@ class ModelGraph:
 
         return parents
 
-    def vars_to_plot(self, var_names: Optional[Iterable[VarName]] = None) -> List[VarName]:
+    def vars_to_plot(self, var_names: Optional[Iterable[VarName]] = None) -> list[VarName]:
         if var_names is None:
             return self._all_var_names
 
@@ -114,9 +116,9 @@ class ModelGraph:
 
     def make_compute_graph(
         self, var_names: Optional[Iterable[VarName]] = None
-    ) -> Dict[VarName, Set[VarName]]:
+    ) -> dict[VarName, set[VarName]]:
         """Get map of var_name -> set(input var names) for the model"""
-        input_map: Dict[VarName, Set[VarName]] = defaultdict(set)
+        input_map: dict[VarName, set[VarName]] = defaultdict(set)
 
         for var_name in self.vars_to_plot(var_names):
             var = self.model[var_name]
@@ -197,7 +199,7 @@ class ModelGraph:
         else:
             graph.node(var_name.replace(":", "&"), **kwargs)
 
-    def get_plates(self, var_names: Optional[Iterable[VarName]] = None) -> Dict[str, Set[VarName]]:
+    def get_plates(self, var_names: Optional[Iterable[VarName]] = None) -> dict[str, set[VarName]]:
         """Rough but surprisingly accurate plate detection.
 
         Just groups by the shape of the underlying distribution.  Will be wrong
@@ -237,7 +239,14 @@ class ModelGraph:
 
         return dict(plates)
 
-    def make_graph(self, var_names: Optional[Iterable[VarName]] = None, formatting: str = "plain"):
+    def make_graph(
+        self,
+        var_names: Optional[Iterable[VarName]] = None,
+        formatting: str = "plain",
+        save=None,
+        figsize=None,
+        dpi=300,
+    ):
         """Make graphviz Digraph of PyMC model
 
         Returns
@@ -270,6 +279,18 @@ class ModelGraph:
             for parent in parents:
                 graph.edge(parent.replace(":", "&"), child.replace(":", "&"))
 
+        if save is not None:
+            width, height = (None, None) if figsize is None else figsize
+            base, ext = path.splitext(save)
+            if ext:
+                ext = ext.replace(".", "")
+            else:
+                ext = "png"
+            graph_c = graph.copy()
+            graph_c.graph_attr.update(size=f"{width},{height}!")
+            graph_c.graph_attr.update(dpi=str(dpi))
+            graph_c.render(filename=base, format=ext, cleanup=True)
+
         return graph
 
     def make_networkx(
@@ -398,6 +419,9 @@ def model_to_graphviz(
     *,
     var_names: Optional[Iterable[VarName]] = None,
     formatting: str = "plain",
+    save: Optional[str] = None,
+    figsize: Optional[tuple[int, int]] = None,
+    dpi: int = 300,
 ):
     """Produce a graphviz Digraph from a PyMC model.
 
@@ -417,6 +441,14 @@ def model_to_graphviz(
         Subset of variables to be plotted that identify a subgraph with respect to the entire model graph
     formatting : str, optional
         one of { "plain" }
+    save : str, optional
+        If provided, an image of the graph will be saved to this location. The format is inferred from
+        the file extension.
+    figsize : tuple[int, int], optional
+        Width and height of the figure in inches. If not provided, uses the default figure size. It only affect
+        the size of the saved figure.
+    dpi : int, optional
+        Dots per inch. It only affects the resolution of the saved figure. The default is 300.
 
     Examples
     --------
@@ -442,6 +474,15 @@ def model_to_graphviz(
             obs = Normal("obs", theta, sigma=sigma, observed=y)
 
         model_to_graphviz(schools)
+
+    Note that this code automatically plots the graph if executed in a Jupyter notebook.
+    If executed non-interactively, such as in a script or python console, the graph
+    needs to be rendered explicitly:
+
+    .. code-block:: python
+
+        # creates the file `schools.pdf`
+        model_to_graphviz(schools).render("schools")
     """
     if "plain" not in formatting:
         raise ValueError(f"Unsupported formatting for graph nodes: '{formatting}'. See docstring.")
@@ -452,4 +493,10 @@ def model_to_graphviz(
             stacklevel=2,
         )
     model = pm.modelcontext(model)
-    return ModelGraph(model).make_graph(var_names=var_names, formatting=formatting)
+    return ModelGraph(model).make_graph(
+        var_names=var_names,
+        formatting=formatting,
+        save=save,
+        figsize=figsize,
+        dpi=dpi,
+    )
