@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -123,9 +123,7 @@ def str_for_model(model: Model, formatting: str = "plain", include_params: bool
             \begin{{array}}{{rcl}}
             {}
             \end{{array}}
-            $$""".format(
-            "\\\\".join(var_reprs)
-        )
+            $$""".format("\\\\".join(var_reprs))
     else:
         # align vars on their ~
         names = [s[: s.index("~") - 1] for s in var_reprs]
