@@ -200,7 +200,7 @@ def compile_forward_sampling_function(
     # Walk the graph from inputs to outputs and tag the volatile variables
     nodes: list[Variable] = general_toposort(
         fg.outputs, deps=lambda x: x.owner.inputs if x.owner else []
-    )
+    )  # type: ignore
     volatile_nodes: set[Any] = set()
     for node in nodes:
         if (
@@ -711,9 +711,14 @@ def sample_posterior_predictive(
 
     .. code:: python
 
-        expanded_data = idata.posterior.expand_dims(pred_id=5)
+        expanded_idata = idata.copy()
+        expanded_idata.posterior = idata.posterior.expand_dims(pred_id=5)
         with model:
-            idata.extend(pm.sample_posterior_predictive(expanded_data))
+            pm.sample_posterior_predictive(
+                expanded_idata,
+                sample_dims=["chain", "draw", "pred_id"],
+                extend_inferencedata=True,
+            )
 
 
     """
