@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -15,7 +15,8 @@ import dataclasses
 import enum
 import logging
 
-from typing import Any, Dict, List, Optional, Sequence
+from collections.abc import Sequence
+from typing import Any, Optional
 
 import arviz
 
@@ -60,21 +61,29 @@ class SamplerWarning:
     divergence_info: Optional[Any] = None
 
 
-def run_convergence_checks(idata: arviz.InferenceData, model) -> List[SamplerWarning]:
+def run_convergence_checks(idata: arviz.InferenceData, model) -> list[SamplerWarning]:
+    warnings: list[SamplerWarning] = []
+
     if not hasattr(idata, "posterior"):
         msg = "No posterior samples. Unable to run convergence checks"
         warn = SamplerWarning(WarningType.BAD_PARAMS, msg, "info", None, None, None)
-        return [warn]
+        warnings.append(warn)
+        return warnings
+
+    warnings += warn_divergences(idata)
+    warnings += warn_treedepth(idata)
 
     if idata["posterior"].sizes["draw"] < 100:
         msg = "The number of samples is too small to check convergence reliably."
         warn = SamplerWarning(WarningType.BAD_PARAMS, msg, "info", None, None, None)
-        return [warn]
+        warnings.append(warn)
+        return warnings
 
     if idata["posterior"].sizes["chain"] == 1:
         msg = "Only one chain was sampled, this makes it impossible to run some convergence checks"
         warn = SamplerWarning(WarningType.BAD_PARAMS, msg, "info")
-        return [warn]
+        warnings.append(warn)
+        return warnings
 
     elif idata["posterior"].sizes["chain"] < 4:
         msg = (
@@ -82,9 +91,8 @@ def run_convergence_checks(idata: arviz.InferenceData, model) -> List[SamplerWar
             "convergence diagnostics"
         )
         warn = SamplerWarning(WarningType.BAD_PARAMS, msg, "info")
-        return [warn]
+        warnings.append(warn)
 
-    warnings: List[SamplerWarning] = []
     valid_name = [rv.name for rv in model.free_RVs + model.deterministics]
     varnames = []
     for rv in model.free_RVs:
@@ -98,7 +106,6 @@ def run_convergence_checks(idata: arviz.InferenceData, model) -> List[SamplerWar
     ess = arviz.ess(idata, var_names=varnames)
     rhat = arviz.rhat(idata, var_names=varnames)
 
-    warnings = []
     rhat_max = max(val.max() for val in rhat.values())
     if rhat_max > 1.01:
         msg = (
@@ -120,13 +127,10 @@ def run_convergence_checks(idata: arviz.InferenceData, model) -> List[SamplerWar
         warn = SamplerWarning(WarningType.CONVERGENCE, msg, "error", extra=ess)
         warnings.append(warn)
 
-    warnings += warn_divergences(idata)
-    warnings += warn_treedepth(idata)
-
     return warnings
 
 
-def warn_divergences(idata: arviz.InferenceData) -> List[SamplerWarning]:
+def warn_divergences(idata: arviz.InferenceData) -> list[SamplerWarning]:
     """Checks sampler stats and creates a list of warnings about divergences."""
     sampler_stats = idata.get("sample_stats", None)
     if sampler_stats is None:
@@ -148,7 +152,7 @@ def warn_divergences(idata: arviz.InferenceData) -> List[SamplerWarning]:
     return [warning]
 
 
-def warn_treedepth(idata: arviz.InferenceData) -> List[SamplerWarning]:
+def warn_treedepth(idata: arviz.InferenceData) -> list[SamplerWarning]:
     """Checks sampler stats and creates a list of warnings about tree depth."""
     sampler_stats = idata.get("sample_stats", None)
     if sampler_stats is None:
@@ -160,7 +164,7 @@ def warn_treedepth(idata: arviz.InferenceData) -> List[SamplerWarning]:
 
     warnings = []
     for c in rmtd.chain:
-        if sum(rmtd.sel(chain=c)) / rmtd.sizes["draw"] > 0.05:
+        if (rmtd.sel(chain=c).mean("draw") > 0.05).any():
             warnings.append(
                 SamplerWarning(
                     WarningType.TREEDEPTH,
@@ -182,7 +186,7 @@ def log_warnings(warnings: Sequence[SamplerWarning]):
         log_warning(warn)
 
 
-def log_warning_stats(stats: Sequence[Dict[str, Any]]):
+def log_warning_stats(stats: Sequence[dict[str, Any]]):
     """Logs 'warning' stats if present."""
     if stats is None:
         return
