@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -13,8 +13,10 @@
 #   limitations under the License.
 import functools as ft
 import itertools as it
+import warnings
 
-from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
+from collections.abc import Sequence
+from typing import Any, Callable, Optional, Union
 
 import numpy as np
 import pytensor
@@ -52,9 +54,8 @@ fast_unstable_sampling_mode = (
     # Remove slow rewrite phases
     .excluding("canonicalize", "specialize")
     # Include necessary rewrites for proper logp handling
-    .including("remove_TransformedVariables").register(
-        (in2out(local_check_parameter_to_ninf_switch), -1)
-    )
+    .including("remove_TransformedVariables")
+    .register((in2out(local_check_parameter_to_ninf_switch), -1))
 )
 
 
@@ -62,11 +63,12 @@ def product(domains, n_samples=-1):
     """Get an iterator over a product of domains.
 
     Args:
+    ----
         domains: a dictionary of (name, object) pairs, where the objects
                  must be "domain-like", as in, have a `.vals` property
         n_samples: int, maximum samples to return.  -1 to return whole product
 
-    Returns
+    Returns:
     -------
         list of the cartesian product of the domains
     """
@@ -142,7 +144,7 @@ class Domain:
 class ProductDomain:
     def __init__(self, domains):
         self.vals = list(it.product(*(d.vals for d in domains)))
-        self.shape = (len(domains),) + domains[0].shape
+        self.shape = (len(domains), *domains[0].shape)
         self.lower = [d.lower for d in domains]
         self.upper = [d.upper for d in domains]
         self.dtype = domains[0].dtype
@@ -212,7 +214,7 @@ Runif = Domain([-np.inf, -0.4, 0, 0.4, np.inf])
 Rdunif = Domain([-np.inf, -1, 0, 1, np.inf], "int64")
 Rplusunif = Domain([0, 0.5, np.inf])
 Rplusdunif = Domain([0, 10, np.inf], "int64")
-I = Domain([-np.inf, -3, -2, -1, 0, 1, 2, 3, np.inf], "int64")
+I = Domain([-np.inf, -3, -2, -1, 0, 1, 2, 3, np.inf], "int64")  # noqa E741
 NatSmall = Domain([0, 3, 4, 5, np.inf], "int64")
 Nat = Domain([0, 1, 2, 3, np.inf], "int64")
 NatBig = Domain([0, 1, 2, 3, 5000, np.inf], "int64")
@@ -247,8 +249,8 @@ def build_model(distfam, valuedomain, vardomains, extra_args=None):
 
 def create_dist_from_paramdomains(
     pymc_dist: Distribution,
-    paramdomains: Dict[str, Domain],
-    extra_args: Optional[Dict[str, Any]] = None,
+    paramdomains: dict[str, Domain],
+    extra_args: Optional[dict[str, Any]] = None,
 ) -> TensorVariable:
     """Create a PyMC distribution from a dictionary of parameter domains.
 
@@ -270,8 +272,8 @@ def create_dist_from_paramdomains(
 
 
 def find_invalid_scalar_params(
-    paramdomains: Dict["str", Domain]
-) -> Dict["str", Tuple[Union[None, float], Union[None, float]]]:
+    paramdomains: dict["str", Domain],
+) -> dict["str", tuple[Union[None, float], Union[None, float]]]:
     """Find invalid parameter values from bounded scalar parameter domains.
 
     For use in `check_logp`-like testing helpers.
@@ -300,12 +302,12 @@ def find_invalid_scalar_params(
 def check_logp(
     pymc_dist: Distribution,
     domain: Domain,
-    paramdomains: Dict[str, Domain],
+    paramdomains: dict[str, Domain],
     scipy_logp: Callable,
     decimal: Optional[int] = None,
     n_samples: int = 100,
-    extra_args: Optional[Dict[str, Any]] = None,
-    scipy_args: Optional[Dict[str, Any]] = None,
+    extra_args: Optional[dict[str, Any]] = None,
+    scipy_args: Optional[dict[str, Any]] = None,
     skip_paramdomain_outside_edge_test: bool = False,
 ) -> None:
     """
@@ -406,7 +408,7 @@ def check_logp(
 def check_logcdf(
     pymc_dist: Distribution,
     domain: Domain,
-    paramdomains: Dict[str, Domain],
+    paramdomains: dict[str, Domain],
     scipy_logcdf: Callable,
     decimal: Optional[int] = None,
     n_samples: int = 100,
@@ -519,7 +521,7 @@ def check_logcdf(
 
 def check_icdf(
     pymc_dist: Distribution,
-    paramdomains: Dict[str, Domain],
+    paramdomains: dict[str, Domain],
     scipy_icdf: Callable,
     skip_paramdomain_outside_edge_test=False,
     decimal: Optional[int] = None,
@@ -616,7 +618,7 @@ def check_icdf(
 def check_selfconsistency_discrete_logcdf(
     distribution: Distribution,
     domain: Domain,
-    paramdomains: Dict[str, Domain],
+    paramdomains: dict[str, Domain],
     decimal: Optional[int] = None,
     n_samples: int = 100,
 ) -> None:
@@ -653,33 +655,41 @@ def check_selfconsistency_discrete_logcdf(
 
 
 def assert_moment_is_expected(model, expected, check_finite_logp=True):
+    warnings.warn(
+        "assert_moment_is_expected is deprecated. Use assert_support_point_is_expected instead.",
+        FutureWarning,
+    )
+    assert_support_point_is_expected(model, expected, check_finite_logp=check_finite_logp)
+
+
+def assert_support_point_is_expected(model, expected, check_finite_logp=True):
     fn = make_initial_point_fn(
         model=model,
         return_transformed=False,
-        default_strategy="moment",
+        default_strategy="support_point",
     )
-    moment = fn(0)["x"]
+    support_point = fn(0)["x"]
     expected = np.asarray(expected)
     try:
         random_draw = model["x"].eval()
     except NotImplementedError:
-        random_draw = moment
+        random_draw = support_point
 
-    assert moment.shape == expected.shape
+    assert support_point.shape == expected.shape
     assert expected.shape == random_draw.shape
-    assert np.allclose(moment, expected)
+    assert np.allclose(support_point, expected)
 
     if check_finite_logp:
-        logp_moment = (
+        logp_support_point = (
             transformed_conditional_logp(
                 (model["x"],),
-                rvs_to_values={model["x"]: pt.constant(moment)},
+                rvs_to_values={model["x"]: pt.constant(support_point)},
                 rvs_to_transforms={},
             )[0]
             .sum()
             .eval()
         )
-        assert np.isfinite(logp_moment)
+        assert np.isfinite(logp_support_point)
 
 
 def continuous_random_tester(
@@ -837,12 +847,12 @@ class BaseTestDistributionRandom:
     reference_dist: Optional[Callable] = None
     reference_dist_params: Optional[dict] = None
     expected_rv_op_params: Optional[dict] = None
-    checks_to_run: List[str] = []
+    checks_to_run: list[str] = []
     size = 15
     decimal = select_by_precision(float64=6, float32=3)
 
-    sizes_to_check: Optional[List] = None
-    sizes_expected: Optional[List] = None
+    sizes_to_check: Optional[list] = None
+    sizes_expected: Optional[list] = None
     repeated_params_shape = 5
     random_state = None
 
