@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 
 import collections
 
-from typing import Callable, Dict
+from typing import Callable
 
 import numpy as np
 
@@ -36,7 +36,7 @@ def absolute(current: np.ndarray, prev: np.ndarray) -> np.ndarray:
     return np.abs(diff)
 
 
-_diff: Dict[str, Callable[[np.ndarray, np.ndarray], np.ndarray]] = dict(
+_diff: dict[str, Callable[[np.ndarray, np.ndarray], np.ndarray]] = dict(
     relative=relative, absolute=absolute
 )
 
