@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -47,10 +47,7 @@ from pytensor.tensor.random.op import RandomVariable
 from pytensor.tensor.subtensor import (
     AdvancedIncSubtensor,
     AdvancedIncSubtensor1,
-    AdvancedSubtensor,
-    AdvancedSubtensor1,
     IncSubtensor,
-    Subtensor,
 )
 
 import pymc as pm
@@ -74,7 +71,7 @@ def test_factorized_joint_logprob_basic():
     a_value_var = a.clone()
 
     a_logp = conditional_logp({a: a_value_var})
-    a_logp_comb = tuple(a_logp.values())[0]
+    a_logp_comb = next(iter(a_logp.values()))
     a_logp_exp = logp(a, a_value_var)
 
     assert equal_computations([a_logp_comb], [a_logp_exp])
