@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -17,7 +17,7 @@ import traceback
 import unittest
 import warnings
 
-from unittest.mock import MagicMock, patch
+from unittest.mock import patch
 
 import arviz as az
 import cloudpickle
@@ -32,10 +32,10 @@ import scipy.sparse as sps
 import scipy.stats as st
 
 from pytensor.graph import graph_inputs
-from pytensor.raise_op import Assert, assert_op
+from pytensor.raise_op import Assert
 from pytensor.tensor import TensorVariable
 from pytensor.tensor.random.op import RandomVariable
-from pytensor.tensor.sharedvar import ScalarSharedVariable
+from pytensor.tensor.sharedvar import TensorSharedVariable
 from pytensor.tensor.variable import TensorConstant
 
 import pymc as pm
@@ -416,7 +416,7 @@ def test_multiple_observed_rv():
     y2_data = np.random.randn(100)
     with pm.Model() as model:
         mu = pm.Normal("mu")
-        x = pm.CustomDist(  # pylint: disable=unused-variable
+        x = pm.CustomDist(
             "x", mu, logp=lambda value, mu: pm.Normal.logp(value, mu, 1.0), observed=0.1
         )
     assert not model["x"] == model["mu"]
@@ -823,7 +823,7 @@ def test_add_coord_mutable_kwarg():
         m.add_coord("fixed", values=[1], mutable=False)
         m.add_coord("mutable1", values=[1, 2], mutable=True)
         assert isinstance(m._dim_lengths["fixed"], TensorConstant)
-        assert isinstance(m._dim_lengths["mutable1"], ScalarSharedVariable)
+        assert isinstance(m._dim_lengths["mutable1"], TensorSharedVariable)
         pm.MutableData("mdata", np.ones((1, 2, 3)), dims=("fixed", "mutable1", "mutable2"))
         assert isinstance(m._dim_lengths["mutable2"], TensorVariable)
 
@@ -1418,8 +1418,8 @@ class TestImputationMissingData:
                     a=[1, 2, 3],
                     observed=np.array([[0.3, 0.3, 0.4], [np.nan, np.nan, np.nan]]),
                 )
-        assert (m_miss["x_unobserved"].owner.op, pm.Dirichlet)
-        assert (m_miss["x_observed"].owner.op, pm.Dirichlet)
+        assert isinstance(m_miss["x_unobserved"].owner.op, pm.Dirichlet)
+        assert isinstance(m_miss["x_observed"].owner.op, pm.Dirichlet)
 
         with pm.Model() as m_unobs:
             x = pm.Dirichlet("x", a=[1, 2, 3], shape=(1, 3))
@@ -1690,10 +1690,20 @@ class TestModelGraphs:
     @pytest.mark.parametrize(
         argnames="var_names", argvalues=[None, ["mu", "tau"]], ids=["all", "subset"]
     )
-    def test_graphviz_call_function(self, var_names) -> None:
+    @pytest.mark.parametrize(
+        argnames="filenames",
+        argvalues=["model.png", "model"],
+        ids=["ext", "no_ext"],
+    )
+    def test_graphviz_call_function(self, var_names, filenames) -> None:
         model = self.school_model(J=8)
         with patch("pymc.model.core.model_to_graphviz") as mock_model_to_graphviz:
-            model.to_graphviz(var_names=var_names)
+            model.to_graphviz(var_names=var_names, save=filenames)
             mock_model_to_graphviz.assert_called_once_with(
-                model=model, var_names=var_names, formatting="plain"
+                model=model,
+                var_names=var_names,
+                formatting="plain",
+                save=filenames,
+                figsize=None,
+                dpi=300,
             )
