@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -117,7 +117,7 @@ def _make_along_axis_idx(arr_shape, indices, axis):
     if str(indices.dtype) not in int_types:
         raise IndexError("`indices` must be an integer array")
     shape_ones = (1,) * indices.ndim
-    dest_dims = list(range(axis)) + [None] + list(range(axis + 1, indices.ndim))
+    dest_dims = [*list(range(axis)), None, *list(range(axis + 1, indices.ndim))]
 
     # build a fancy index, consisting of orthogonal aranges, with the
     # requested index inserted at the right location
@@ -583,7 +583,7 @@ class TestCompilePyMC:
             n_steps=10,
         )
 
-        assert collect_default_updates([ys]) == {rng: tuple(next_rng.values())[0]}
+        assert collect_default_updates([ys]) == {rng: next(iter(next_rng.values()))}
 
         fn = compile_pymc([], ys, random_seed=1)
         assert not (set(fn()) & set(fn()))
@@ -694,7 +694,8 @@ def test_replace_vars_in_graphs_nested_reference():
     # Confirm the original `y` variable is changed in place
     # This is unavoidable if we want to respect the identity of the replacement variables
     # As when imputing `neg_x` and `x` while evaluating `new_y` above and below.
-    assert np.abs(y.eval({x_value: 100})) > 1
+    # This assertion could fail with probability 1/10000
+    assert np.abs(y.eval({x_value: 10000})) > 1
 
     # Only replace `y`, same replacement as before
     x = pm.HalfNormal.dist(1e-3, name="x")
